
IF OBJECT_ID('dbo.tRws') IS NOT NULL 
BEGIN
    DROP TABLE dbo.tRws
END

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.PortalPatronObten_asp_ds')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.PortalPatronObten_asp_ds
GO


CREATE PROCEDURE dbo.PortalPatronObten_asp_ds
    @keyId udtLong ,
    @ncodigo NUMERIC(8, 0) ,
    @nayo INT ,
    @nmes INT ,
    @dfch_fin_mes DATETIME
AS 
    DECLARE @ninicio NUMERIC(8, 0)
    DECLARE @nfin NUMERIC(8, 0)

    IF @ncodigo = 0 
        BEGIN 
            SET @ninicio = 1
            SET @nfin = 99999999
        END
    ELSE 
        BEGIN
            SET @ninicio = @ncodigo
            SET @nfin = @ncodigo
        END

    UPDATE  a
    SET     a.diastr = 0
    FROM    dbo.avisos_imss AS a
            INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa
                                                         AND b.llave = @keyId
    WHERE   a.ayo_operacion = @nayo
            AND a.mes_operacion = @nmes
            AND a.codigo BETWEEN @ninicio AND @nfin        

    UPDATE  a
    SET     a.diastr = CASE WHEN a.mov = 'B' THEN 0
                            ELSE CASE WHEN a.fch_mov = d.fch_mov
                                           AND d.mov <> 'B' THEN 0
                                      ELSE CASE WHEN d.fch_mov IS NULL
                                                THEN DATEDIFF(dd, a.fch_mov,
                                                              @dfch_fin_mes)
                                                     + 1
                                                ELSE DATEDIFF(dd, a.fch_mov,
                                                              d.fch_mov)
                                                     + CASE WHEN d.mov = 'B'
                                                            THEN 1
                                                            ELSE 0
                                                       END
                                           END
                                 END
                       END
    FROM    dbo.avisos_imss AS a
            INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa
                                                         AND b.llave = @keyId
            LEFT JOIN dbo.avisos_imss AS d ON a.empresa = d.empresa
                                              AND a.codigo = d.codigo
                                              AND a.ayo_operacion = d.ayo_operacion
                                              AND a.mes_operacion = d.mes_operacion
                                              AND a.serial + 1 = d.serial
    WHERE   a.ayo_operacion = @nayo
            AND a.mes_operacion = @nmes
            AND a.codigo BETWEEN @ninicio AND @nfin

GO


IF OBJECT_ID('dbo.reportePatronEmpleados') IS NOT NULL 
BEGIN
    DROP TABLE dbo.reportePatronEmpleados
END


IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'PortalPatronObtenListadoAosRecibos'
                    AND type = 'P' ) 
    DROP PROCEDURE PortalPatronObtenListadoAosRecibos
GO

CREATE PROCEDURE PortalPatronObtenListadoAosRecibos
(
	@llave udtLong
)
    --WITH ENCRYPTION
AS 
    SELECT DISTINCT
            ( k.ayo_operacion )
    FROM    dbo.kardex_anual AS k
    INNER JOIN dbo.tmpAccesoPortalPatron AS tmp ON k.empresa = tmp.empresa AND tmp.llave=@llave
    ORDER BY k.ayo_operacion DESC

GO


IF EXISTS ( SELECT  name
            FROM    sysobjects
            WHERE   name = 'PortalPatronObtenTiposnomRecibos'
                    AND type = 'P' ) 
    DROP PROCEDURE PortalPatronObtenTiposnomRecibos
GO

CREATE PROCEDURE PortalPatronObtenTiposnomRecibos ( @ao udtInteger,@llave udtLong )
    --WITH ENCRYPTION
AS 
    SELECT	replicate('0',2 - len(ltrim(str(k.tiponom)))) + ltrim(str(k.tiponom)) + ' ' + rtrim(n.nomina) as nomina
    FROM    dbo.kardex_anual AS k
    inner join  nominas as n on k.empresa=n.empresa and k.tiponom=n.tiponom
    INNER JOIN dbo.tmpAccesoPortalPatron AS tmp ON n.empresa = tmp.empresa AND llave=@llave
    WHERE   k.ayo_operacion = @ao
    group by k.tiponom,n.nomina
    ORDER BY k.tiponom 

GO

IF EXISTS ( SELECT
                name
            FROM
                sysobjects
            WHERE
                name = 'PortalPatronObtenPeriodosRecibos' AND
                type = 'P' ) 
    DROP PROCEDURE PortalPatronObtenPeriodosRecibos
GO

CREATE PROCEDURE PortalPatronObtenPeriodosRecibos
(
	@ao udtInteger,
	@tiponom udtInteger,
	@llave udtLong
)

	--WITH ENCRYPTION
AS

SELECT REPLICATE('0',2 - LEN(LTRIM(STR(k.periodo))) )+ LTRIM(STR(k.periodo)) AS periodo
FROM dbo.kardex_anual AS k
INNER JOIN dbo.tmpAccesoPortalPatron AS tmp ON k.empresa = tmp.empresa AND tmp.llave=@llave
WHERE k.ayo_operacion=@ao AND k.tiponom=@tiponom
GROUP BY k.periodo
ORDER BY k.periodo DESC

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronAosReportes')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronAosReportes
GO


CREATE PROCEDURE dbo.Obten_PortalPatronAosReportes
(
	@llave udtLong,
	@nReport udtInteger
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

	
	Declare @ayos as table(Ayo int)

	insert into @ayos
	SELECT DISTINCT(ayo_operacion) as Ayo 
	FROM   dbo.kardex_anual AS a 
	INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa 
	WHERE b.llave = @llave
	ORDER BY a.ayo_operacion DESC 

	if isnull((select top 1 1 from @ayos),0)<=0
	begin 
		insert into @ayos
		select 0
	end

	select * from @ayos order by Ayo desc
        
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronTiposNomReportes')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronTiposNomReportes
GO


CREATE PROCEDURE dbo.Obten_PortalPatronTiposNomReportes
(
	@llave udtLong,
	@ao udtInteger,
	@nReport udtInteger
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''

     Declare @TiposNom as table(Tiponom varchar(200),tipo int)
	 insert into @TiposNom
	select	Tiponom,tipo
	from 
	(	SELECT REPLICATE('0',2 - LEN(RTRIM(LTRIM((STR(a.tiponom)))))) + RTRIM(LTRIM(STR(a.tiponom))) + ' ' + n.nomina as Tiponom,a.tiponom as tipo
		FROM   dbo.Periodos AS a
		INNER JOIN dbo.nominas as n on  a.empresa=n.empresa and a.tiponom=n.tiponom
		INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa
		where	b.llave=@llave
				and a.ayo_operacion = @ao
		GROUP BY a.tiponom,n.nomina

		union 

		select '00 Todas' as Tiponom,0 tipo
		where	 @nReport in(2,6,11,12)

	) as tbl

	select tiponom
	from @TiposNom
	order by tipo
        
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronPeriodosReportes')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronPeriodosReportes
GO


CREATE PROCEDURE dbo.Obten_PortalPatronPeriodosReportes
(
	@tiponom udtInteger,
	@ao udtInteger,
	@llave udtLong,
	@nReport udtInteger
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


	SELECT REPLICATE('0',2 - LEN(RTRIM(LTRIM((STR(a.periodo)))))) + RTRIM(LTRIM(STR(a.periodo))) Periodo
	FROM   dbo.Periodos AS a
	INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa
	where	b.llave=@llave
			and a.ayo_operacion = @ao
			and a.tiponom=@tiponom
	GROUP BY a.periodo
	order by a.periodo desc
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronIncapacidadesAnuales')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronIncapacidadesAnuales
GO


CREATE PROCEDURE dbo.Obten_PortalPatronIncapacidadesAnuales
(    
    @Tiponom udtInteger ,
    @Periodo udtInteger ,
    @Ao     udtInteger ,
    @nTipo udtInteger,
    @llave   udtLong
)

    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
    IF @Tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.tiponom = '
                + LTRIM(RTRIM(STR(@Tiponom)))
                 
        END
        
    IF @Periodo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.periodo = '
                + LTRIM(RTRIM(STR(@Periodo)))
                 
        END
        
    IF @Ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.ayo_operacion = '
                + LTRIM(RTRIM(STR(@Ao)))
                 
        END        
        
        IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.nomina = ''ORD'' '
    

set @selectClause =	 'SELECT tiponom as ''TipoNomina'','
							+'Periodo ,'
							+'Ao ,'
							+ CASE WHEN @nTipo = 1 THEN ' '''' as Departamento,' ELSE 'centro as ''Departamento'',' END 
							+'isnull([108],0) as '' FaltasInjustificadas(108)'','
							+'isnull([109],0) as ''Inc.Enf.Gral.(109)'','
							+'isnull([110],0) as ''Inc.Mat.(110)'','
							+'isnull([111],0) as '' Inc.RT,(111)'','
							+'(isnull([108],0) + isnull([109],0) + isnull([110],0) + isnull([111],0)) * 8 as ''HrsxPeriodo'' '
					 +'FROM   ( SELECT    a.periodo ,'
										+'a.ayo_operacion AS ao ,'
										+'0 as tiponom,'
										+'Sum(ISNULL(a.dias, 0)) AS dias ,'
										+ CASE WHEN @nTipo = 1 THEN ' '''' AS centro,' ELSE 'RTRIM(LTRIM(ISNULL(n.centro,ll.centro))) +  '' '' + RTRIM(LTRIM(c.nomdepto)) AS centro,' END 
										+'a.num_conc '
							  +'FROM      dbo.kardex_anual AS a '
							  + CASE WHEN @nTipo = 1 THEN ' ' ELSE
							   'LEFT JOIN dbo.nomina1_anual AS n ON a.empresa = n.empresa AND a.codigo = n.codigo AND a.periodo = n.periodo AND a.ayo_operacion = n.ayo_operacion AND a.tiponom = n.tiponom '
							  +'INNER JOIN dbo.Llaves AS ll ON a.empresa = ll.empresa AND a.codigo = ll.codigo '
						      +'INNER JOIN dbo.centros AS c ON c.centro = ISNULL(n.centro,ll.centro) AND a.empresa = c.empresa ' END 
							  +'INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa and b.llave= ' + LTRIM(RTRIM(STR(@llave))) + ' '
							  + @whereClause
							  +' GROUP BY a.periodo,a.ayo_operacion,'
							  + CASE WHEN @nTipo = 1 THEN ' ' ELSE 'RTRIM(LTRIM(ISNULL(n.centro,ll.centro))) +  '' '' + RTRIM(LTRIM(c.nomdepto)),' END 
							  + 'a.num_conc '
							+') AS kardex_anual PIVOT '
						+'( SUM(dias) FOR num_conc IN ( [108], [109], [110], [111] ) ) AS PivotTable '
					    +'order by centro,ao,periodo '
					    
					    
					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause )
        END
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronImpuestoSobreNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronImpuestoSobreNomina
GO


CREATE PROCEDURE dbo.Obten_PortalPatronImpuestoSobreNomina
    (
      @Tiponom udtInteger ,
      @Periodo udtInteger ,
      @Ao udtInteger ,
	  @Mes udtname,
      @llave udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
    IF @Tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@Tiponom)))
                 
        END
        
    IF @Periodo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@Periodo)))
                 
        END
        
    IF @Ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@Ao)))
                 
        END        
    
    IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
	                 
    SET @whereClause = @whereClause + ' k.num_conc=216 '

	IF len(@mes) > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = '''+@Mes+''''
                 
        END        
	
    DECLARE @ISN AS TABLE
        (
          Empleados udtLong ,
          Base NUMERIC(10, 2) ,
          [%] NUMERIC(10, 2) ,
          Importe NUMERIC(10, 2) ,
          Centro udtName ,
          [NombreDep] udtName ,
          Empresa udtInteger ,
          grupo udtName ,
          encabezado udtName ,
          IND udtName
        )
	
    SET @selectClause = 'SELECT COUNT( DISTINCT(k.codigo) ) AS Empleados , '
        + 'SUM(k.impor_base) AS Base , ' + 'k.unidades AS ''%'' ,'
        + 'SUM(k.importe) AS Importe ,' + 'l.centro AS Centro ,'
        + 'RTRIM(l.centro) + '' '' + RTRIM(c.nomdepto) AS ''NombreDepartamento'',k.empresa,REPLICATE(''0'',10-LEN(RTRIM(LTRIM( STR(k.empresa))))) + RTRIM(LTRIM(STR(k.empresa))) +''01'','
        + ' ''DEPARTAMENTOS'' '
					    
    SET @fromClause = 'FROM    dbo.kardex_anual AS k '
        + 'INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa '
        + 'AND k.codigo = l.codigo '
        + 'INNER JOIN dbo.centros AS c ON l.empresa = c.empresa '
        + 'AND l.centro = c.centro '
        + 'INNER JOIN dbo.tmpAccesoPortalPatron as b on  k.empresa=b.empresa and b.llave= '
        + LTRIM(RTRIM(STR(@llave))) 
											    

    SET @groupByClause = ' GROUP BY k.empresa,REPLICATE(''0'',10-LEN(RTRIM(LTRIM( STR(k.empresa))))) + RTRIM(LTRIM(STR(k.empresa))),l.centro ,c.nomdepto ,k.unidades '
    SET @orderByClause = ' ORDER BY k.empresa,REPLICATE(''0'',10-LEN(RTRIM(LTRIM( STR(k.empresa))))) + RTRIM(LTRIM(STR(k.empresa))),l.centro '

	print
                ( @selectClause + @fromClause + @whereClause + @groupByClause
                  + @orderByClause
                )
						    
    INSERT  INTO @ISN
            ( Empleados ,
              Base ,
              [%] ,
              Importe ,
              Centro ,
              NombreDep ,
              Empresa ,
              grupo ,
              encabezado
            )
            EXEC
                ( @selectClause + @fromClause + @whereClause + @groupByClause
                  + @orderByClause
                )
    DECLARE @tmpEmpresas AS TABLE
        (
          empresa udtInteger ,
          serial udtLong
        )
    INSERT  INTO @tmpEmpresas
            SELECT  a.empresa ,
                    dense_rank() OVER ( PARTITION  BY a.llave ORDER BY a.empresa ) serial
            FROM    dbo.tmpAccesoPortalPatron AS a
                    INNER JOIN @ISN AS b ON a.empresa = b.Empresa
            WHERE   a.llave = @llave
            GROUP BY a.llave ,
                    a.empresa
            
    DECLARE @min udtLong
    DECLARE @max udtLong
    DECLARE @serialMet udtLong
    DECLARE @sqlString udtStringSize4096

    SET @serialMet = 1

    SELECT  @min = MIN(serial) ,
            @max = MAX(serial)
    FROM    @tmpEmpresas


    WHILE @serialMet <= @max 
        BEGIN

            SELECT  @sqlString = 'select null,null,null,null, MAX(concepto),null, '
                    + ' num_conc,REPLICATE(''0'',10-LEN(RTRIM(LTRIM( STR(empresa))))) + RTRIM(LTRIM(STR(empresa))) +''02'','
                    + ' ''CONCEPTOS CONSIDERADOS'','
                    + '  case when ((num_conc >= 1 AND num_conc <= 99)OR(num_conc >= 501 AND num_conc <= 599)OR ( num_conc >= 1100 AND num_conc <= 1199)) then ''+'' else ''-'' end'
                    + ' from conceptos '
                    + ' where num_conc in('
                    + SUBSTRING(a.totales, CHARINDEX('{', a.totales) + 1,
                                CHARINDEX('}', a.totales) - 2) + ')'
                    + ' AND empresa=' + RTRIM(LTRIM(STR(a.empresa)))
                    + ' group by empresa,num_conc'
            FROM    dbo.conceptos AS a
                    INNER JOIN @tmpEmpresas AS b ON a.empresa = b.empresa
            WHERE   a.num_conc = 216
                    AND b.serial = @serialMet
	
            INSERT  INTO @ISN
                    ( Empleados ,
                      Base ,
                      [%] ,
                      Importe ,
                      NombreDep ,
                      Centro ,
                      Empresa ,
                      grupo ,
                      encabezado ,
                      IND
                    
                    )
                    EXEC ( @sqlString
                        )
	
            SET @serialMet = @serialMet + 1

        END
    
    
    INSERT  INTO @ISN
                    ( Empleados ,
                      Base ,
                      [%] ,
                      Importe ,
                      NombreDep ,
                      Centro ,
                      Empresa ,
                      grupo ,
                      encabezado ,
                      IND)
    SELECT  SUM(Empleados) ,
            SUM(Base) ,
            NULL ,
            SUM(Importe) ,
            NombreDep AS 'Nombre Departamento' ,
            Centro ,
            NULL ,
            '9999999999',
            'TOTAL GENERAL' ,
            ''
    FROM    @ISN
    WHERE Importe>0
    GROUP BY Centro ,
            NombreDep
     
    
    SELECT  Empleados ,
            Base ,
            [%] ,
            Importe ,
            Centro ,
            NombreDep AS 'NombreDepartamento' ,
            Empresa ,
            grupo ,
            encabezado ,
            IND
    FROM    @ISN
    ORDER BY grupo
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronEmpleadosActivos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronEmpleadosActivos
GO


CREATE PROCEDURE dbo.Obten_PortalPatronEmpleadosActivos
    (
      @keyid udtInteger,
      @beginDate udtDateTime
    )
    --WITH ENCRYPTION
AS 

DECLARE @mes_operacion udtInteger
DECLARE @ayo_operacion udtInteger
DECLARE @fechaFinMes udtDateTime

SET @mes_operacion = MONTH(@beginDate)
SET @ayo_operacion = YEAR(@beginDate)
SET @fechaFinMes =(SELECT dbo.fin_mes(@mes_operacion,@ayo_operacion))

EXECUTE dbo.PortalPatronObten_asp_ds @keyId,0,@ayo_operacion,@mes_operacion,@fechaFinMes -- datetime



SELECT DISTINCT codigo,empresa
FROM dbo.avisos_imss
WHERE @beginDate >= fch_mov
      AND @beginDate <= fch_mov + diastr - 1 --CASE WHEN mov = 'B' THEN 0 ELSE 1 END
      AND mov <> 'B'
ORDER BY codigo

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronMesesReportes')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronMesesReportes
GO


CREATE PROCEDURE dbo.Obten_PortalPatronMesesReportes
(
	@ao udtInteger,
	@llave udtLong,
	@nReport udtInteger
)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 

	select	*
    from (
			SELECT case	when substring(a.mes,1,2) = '01' then 'ENE'
						when substring(a.mes,1,2) = '02' then 'FEB'
						when substring(a.mes,1,2) = '03' then 'MAR'
						when substring(a.mes,1,2) = '04' then 'ABR'
						when substring(a.mes,1,2) = '05' then 'MAY'
						when substring(a.mes,1,2) = '06' then 'JUN'
						when substring(a.mes,1,2) = '07' then 'JUL'
						when substring(a.mes,1,2) = '08' then 'AGO'
						when substring(a.mes,1,2) = '09' then 'SEP'
						when substring(a.mes,1,2) = '10' then 'OCT'
						when substring(a.mes,1,2) = '11' then 'NOV'
						when substring(a.mes,1,2) = '12' then 'DIC'
					else 'ENE' END
					+ substring(convert(varchar,ayo_operacion),3,2)
					as Mes,
					convert(int,substring(a.mes,1,2)) as mesInt
			FROM   dbo.Periodos AS a
			INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa
			where	b.llave=@llave
					and a.ayo_operacion = @ao
			GROUP BY a.mes,a.ayo_operacion
			) as tbl
	order by mesInt desc
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronGravaExenISR')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronGravaExenISR
GO


CREATE PROCEDURE dbo.Obten_PortalPatronGravaExenISR
    (
      @Tiponom udtInteger ,
      @Periodo udtInteger ,
      @Ao udtInteger ,
      @Mes udtName,
      @llave udtLong
    )
    --WITH ENCRYPTION
    
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger
    
    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
	IF @tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @periodo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END

	IF @ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@ao)))
                 
        END
    
    

	IF @mes <> ''
        BEGIN
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ' + '''' + @mes  + ''''
                  
        END

	IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
				SET @whereClause = @whereClause + ' AND '
				SET @whereClause = @whereClause + ' k.TPago_Desc IN (''P'',''D'') '
				
				

SET @selectClause = 'SELECT ISNULL(n.Centro,l.Centro) AS Centro,'
             +' MAX(c.NomDepto) AS NomDepto, '
             +' SUM(CASE WHEN k.Num_Conc <= 7 OR k.Num_Conc = 30'
                      +' THEN k.Dias'
                      +' ELSE CASE WHEN k.Num_Conc IN (107,108,109,110)'
                                +' THEN 0.00-k.Dias'
                                +' ELSE 0'
                           +' END'
                 +' END) -  '
             +' SUM(CASE WHEN k.Num_Conc = 108 OR (k.Num_Conc = 107 AND k.Justificar IN (''F'',''P'',''S'',''T''))'
                      +' THEN k.Dias'
                      +' ELSE 0'
                 +' END) - '
             +' SUM(CASE WHEN k.Num_Conc IN (109,110,111) OR (k.Num_Conc = 107 AND k.Justificar IN (''1'',''2'',''3''))'
                      +' THEN k.Dias'
                      +' ELSE 0'
                 +' END) AS Dias,'
             +' SUM(CASE WHEN k.TPago_Desc = ''P'' THEN isnull(k.Importe,0) ELSE 0.00-k.Importe END) AS Neto,'
             +' SUM(CASE WHEN k.TPago_Desc = ''P'' THEN isnull(k.IGravable,0) ELSE 0 END) AS PercepcionGravable,'
             +' SUM(CASE WHEN k.TPago_Desc = ''P'' THEN isnull(k.IExento,0) ELSE 0 END) AS PercepcionExento,'
             +' SUM(CASE WHEN k.TPago_Desc = ''D'' THEN isnull(k.IGravable,0) ELSE 0 END) AS DeduccionGravable,'
             +' SUM(CASE WHEN k.TPago_Desc = ''D'' THEN isnull(k.IExento,0) ELSE 0 END) AS DeduccionExento,'
             +' SUM(CASE WHEN k.Num_Conc = 36 THEN isnull(k.Importe,0) ELSE 0 END) AS Subsidio,'
             +' SUM(CASE WHEN k.Num_Conc = 136 THEN isnull(k.Importe,0) ELSE 0 END) AS Isr,'
             +' SUM(CASE WHEN k.Num_Conc = 1036 THEN isnull(k.Importe,0) ELSE 0 END) AS ContraSubsidio,'
             +' SUM(CASE WHEN k.Num_Conc = 1136 THEN isnull(k.Importe,0) ELSE 0 END) AS ContraIsr,'
             +' SUM(CASE WHEN k.Num_Conc IN (36,136,1036,1136) THEN isnull(k.Varia1,0) ELSE 0 END) AS SubsidioTotal,'
             +' SUM(CASE WHEN k.Num_Conc NOT IN (36,136,1036,1136) THEN isnull(k.VariaImss,0) ELSE 0 END) AS VariaImss,'
             +' '''' AS Llave,'
             +' (SELECT COUNT(DISTINCT kk.Codigo)'
              +' FROM Kardex_Anual AS kk'
              +' INNER JOIN Nomina1_Anual AS Nomina ON Nomina.Codigo = kk.Codigo AND Nomina.Periodo = kk.Periodo AND Nomina.Ayo_Operacion = kk.Ayo_Operacion AND Nomina.Empresa = kk.Empresa'
              +' INNER JOIN Llaves AS Ll ON Ll.Codigo = kk.Codigo AND Ll.Empresa = kk.Empresa'
              +' INNER JOIN dbo.tmpAccesoPortalPatron as bb on  kk.empresa=bb.empresa and bb.llave= ' + LTRIM(RTRIM(STR(@llave))) 
              +' WHERE ISNULL(Nomina.Centro,Ll.Centro) = ISNULL(n.Centro,l.Centro) AND'
                    +' ISNULL(Nomina.TipoNom,Ll.TipoNom) = ' + LTRIM(RTRIM(STR(@tiponom))) + ' ) AS Registros '

      SET @fromClause = 'FROM Kardex_Anual AS k'
      +' INNER JOIN Empleados AS e ON e.Codigo = k.Codigo AND e.Empresa = k.Empresa'
      +' INNER JOIN Llaves AS l ON l.Codigo = k.Codigo AND l.Empresa = k.Empresa'
      +' LEFT JOIN Nomina1_Anual AS n ON n.Codigo = k.Codigo AND n.TipoNom = k.TipoNom AND n.Periodo = k.Periodo AND n.Ayo_Operacion = k.Ayo_Operacion AND n.Empresa = k.Empresa'
      +' INNER JOIN Centros AS c ON c.Centro = ISNULL(n.Centro,l.Centro) AND c.Empresa = k.Empresa'
      +' INNER JOIN Periodos AS p ON p.TipoNom = k.TipoNom AND p.Periodo = k.Periodo AND p.Ayo_Operacion = k.Ayo_Operacion AND p.Empresa = k.Empresa'
      +' INNER JOIN dbo.tmpAccesoPortalPatron as b on  k.empresa=b.empresa and b.llave= ' + LTRIM(RTRIM(STR(@llave))) 
      
      SET @groupByClause = ' GROUP BY ISNULL(n.Centro,l.Centro) '
	  SET @orderByClause = ' ORDER BY ISNULL(n.Centro,l.Centro) '
					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END



GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalDetalleReciboAhorro')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalDetalleReciboAhorro

GO


CREATE PROCEDURE dbo.Obten_PortalDetalleReciboAhorro
    (
      @empresa udtInteger ,
      @codigo udtInteger ,
      @retiro udtInteger 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    DECLARE @fromClause udtStringSize4096 = ''
    DECLARE @selectClause udtStringSize4096 = ''
    DECLARE @whereClause udtStringSize4096 = ''
    DECLARE @groupByClause udtStringSize4096 = ''
    DECLARE @orderByClause udtStringSize4096 = ''
    DECLARE @title udtStringSize4096 = ''
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    IF OBJECT_ID('dbo.tRws') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tRws
        END
        
    CREATE TABLE  dbo.tRws 
        (
          empresa INT ,
          num_conc_p INT ,
          concepto_p VARCHAR(45) ,
          importe_p NUMERIC(10, 2) ,
          num_conc_d INT ,
          concepto_d VARCHAR(45) ,
          importe_d NUMERIC(10, 2) ,
          neto NUMERIC(10, 2) ,
          percepciones NUMERIC(10, 2) ,
          deducciones NUMERIC(10, 2) ,
          serial INT ,
          grupo INT
        )

    DECLARE @counter INT
    DECLARE @copias AS udtInteger

    SELECT  @copias = isnull(Copias_Recibo,1)
    FROM    dbo.Parametros_Empresas
    WHERE   Empresa = @empresa

    SET @counter = 1 

    WHILE @counter <= 20 
        BEGIN	
            INSERT  INTO dbo.tRws
                    ( empresa, serial, grupo )
            VALUES  ( @empresa, -- empresa - int
                      @counter, -- serial - int
                      1  -- grupo - int
                      )
            SET @counter = @counter + 1
        END

--SET @counter = 1 
    WHILE @counter <= 40
        AND @copias > 1 
        BEGIN 
            INSERT  INTO dbo.tRws
                    ( empresa, serial, grupo )
            VALUES  ( @empresa, -- empresa - int
                      @counter, -- serial - int
                      2  -- grupo - int
                      )
            SET @counter = @counter + 1
        END


    DECLARE @totalRows TABLE
        (
          empresa INT ,
          codigo INT ,
          num_conc_p INT ,
          concepto_p VARCHAR(35) ,
          importe_p NUMERIC(10, 2) ,
          num_conc_d INT ,
          concepto_d VARCHAR(35) ,
          importe_d NUMERIC(10, 2) ,
          percepciones NUMERIC(10, 2) ,
          deducciones NUMERIC(10, 2) ,
          neto NUMERIC(10, 2) ,
          serial INT ,
          grupo VARCHAR(25) ,
          numero INT
        )



    IF @empresa > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.empresa = '
                + LTRIM(RTRIM(STR(@empresa)))
                 
        END
    IF @codigo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.codigo = '
                + LTRIM(RTRIM(STR(@codigo)))
                 
        END
    SET @selectClause = 'SELECT  a.empresa ,' + 'a.codigo,' + 'b.num_conc_p,'
        + 'b.concepto_p,' + 'b.importe_p,' + 'b.num_conc_d,' + 'b.concepto_d,'
        + 'b.importe_d,' + 'b.percepciones,' + 'b.deducciones,' + 'b.neto,'
        + 'b.serial,'
        + 'REPLICATE(''0'',8-LEN(LTRIM(STR(a.codigo))))+LTRIM(STR(a.codigo))+ REPLICATE(''0'',2-LEN(LTRIM(STR(b.grupo))))+LTRIM(STR(b.grupo))+ '+ '''' + REPLICATE('0',2-LEN(LTRIM(STR(isnull(@copias,0)))))+LTRIM(STR(isnull(@copias,0)))+''''+' AS grupo,'
        + 'b.grupo AS numero '
    SET @fromClause = ' FROM    dbo.fondo_de_ahorros AS a '
        + 'INNER JOIN dbo.tRws AS b ON a.empresa = b.empresa '
	
	IF @debug = 0 
        BEGIN
			INSERT  INTO @totalRows
                    ( empresa ,
                      codigo ,
                      num_conc_p ,
                      concepto_p ,
                      importe_p ,
                      num_conc_d ,
                      concepto_d ,
                      importe_d ,
                      percepciones ,
                      deducciones ,
                      neto ,
                      serial ,
                      grupo ,
                      numero
                    )
                    EXEC
                        ( @selectClause + @fromClause + @whereClause
                          + @orderByClause
                        )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @orderByClause )
        END

    SELECT  a.empresa ,
            a.codigo ,
            REPLICATE('0', 8 - LEN(LTRIM(STR(a.codigo)))) + LTRIM(STR(a.codigo))
            + REPLICATE('0', 9 - LEN(LTRIM(STR(a.serial))))
            + LTRIM(STR(a.serial)) AS codigoId ,
            RTRIM(e.ap_paterno) + ' ' + RTRIM(e.ap_materno) + ' '
            + RTRIM(e.nombre) AS nombre ,
            e.fchalta AS fechaAlta ,
            e.afiliacion AS numeroSeguridadSocial ,
            e.digvera AS digitoVerificador ,
            e.curp ,
            l.centro ,
            c.nomdepto AS nombreCentro ,
            e.cta_bco_no AS cuentaBanco ,
            ba.nombre nombreBanco ,
            l.ocupacion ,
            t.actividad AS categoria ,
            e.tiposal AS tipoSalario ,
            a.serial AS renglon ,
            e.jornada ,
            e.sueldo AS sueldoDiario ,
            e.saldiaint AS salarioBaseCotizacion ,
            l.clase ,
            cl.nombre AS nombreClase ,
            l.supervisor ,
            su.nombre AS nombreSupervisor ,
            NULL AS marcaContraPercepcion ,
            NULL AS numeroConceptoPercepcion ,
            CASE WHEN ( a.serial = 1
                        OR a.serial = 21
                      )
                      AND @retiro = 0 THEN 'AP. FONDO DE AHORRO TRABAJADOR'
                 WHEN ( a.serial = 1
                        OR a.serial = 21
                      )
                      AND @retiro = 1 THEN 'RETIRO PARCIAL'
                 WHEN ( a.serial = 2
                        OR a.serial = 22
                      )
                      AND @retiro = 0 THEN 'AP. FONDO DE AHORRO PATRON'
                 WHEN ( a.serial = 3
                        OR a.serial = 23
                      )
                      AND @retiro = 0
                      AND b.intereses > 0 THEN 'INTERESES  GENERADOS'
                 ELSE ''
            END AS nombreConceptoPercepcion ,
            CASE WHEN ( a.serial = 1
                        OR a.serial = 21
                      )
                      AND @retiro = 0 THEN b.importe_p
                 WHEN ( a.serial = 1
                        OR a.serial = 21
                      )
                      AND @retiro = 1 THEN b.retiros
                 WHEN ( a.serial = 2
                        OR a.serial = 22
                      )
                      AND @retiro = 0 THEN b.importe_t
                 WHEN ( a.serial = 3
                        OR a.serial = 23
                      )
                      AND @retiro = 0
                      AND b.intereses > 0 THEN b.intereses
                 ELSE 0
            END AS importeConceptoPercepcion ,
            NULL AS gravablePercepcion ,
            NULL AS exentoPercepcion ,
            NULL AS saldoPercepcion ,
            '' AS anexoConceptoPercepcion ,
            NULL AS marcaContraDeduccion ,
            NULL AS numeroConceptoDeduccion ,
            CASE WHEN ( ( a.serial = 1
                          OR a.serial = 21
                        )
                        AND b.adeudo > 0
                      )
                      AND @retiro = 0 THEN 'ADEUDO DE FONDO DE AHORRO'
                 WHEN ( ( a.serial = 2
                          OR a.serial = 22
                        )
                        AND b.retiros > 0
                      )
                      AND @retiro = 0 THEN 'RETIRO PARCIAL'
                 ELSE ''	
            END AS nombreConceptoDeduccion ,
            CASE WHEN ( ( a.serial = 1
                          OR a.serial = 21
                        )
                        AND b.adeudo > 0
                      )
                      AND @retiro = 0 THEN b.adeudo
                 WHEN ( ( a.serial = 2
                          OR a.serial = 22
                        )
                        AND b.retiros > 0
                      )
                      AND @retiro = 0 THEN b.retiros
                 ELSE 0
            END AS importeConceptoDeduccion ,
            NULL AS gravableDeduccion ,
            NULL AS exentoDeduccion ,
            NULL AS saldoDeduccion ,
            '' AS anexoConceptoDeduccion ,
            NULL AS numeroConceptoProvision ,
            NULL AS nombreConceptoProvision ,
            NULL AS importeConceptoProvision ,
            '' AS detalle ,
            NULL AS empleados ,
            NULL AS provisionIMSS ,
            NULL AS provisionRCV ,
            NULL AS provisionINFONAVIT ,
            NULL AS retencionIMSS ,
            NULL AS retencionRCV ,
            NULL AS retencionINFONAVIT ,
            NULL AS empleadosConCuentaBancaria ,
            NULL AS empleadosSinCuentaBancaria ,
            NULL AS percepcionesConCuentaBancaria ,
            NULL AS deduccionesConCuentaBancaria ,
            NULL AS percepcionesSinCuentaBancaria ,
            NULL AS deduccionesSinCuentaBancaria ,
            NULL AS basePorcientoSobreNomina ,
            NULL AS poricientoSobreNomina ,
            NULL AS impuestoSobreNomina ,
            NULL AS fondoAhorroAportacionEmpleado ,
            NULL AS fondoAhorroAportacionPatron ,
            NULL AS sueldoNetoGeneral ,
            b.ejercicio AS ejercicio ,
            NULL AS diarioOficialDia ,
            NULL AS diarioOficialMes ,
            NULL AS diarioOficialAyo ,
            NULL AS salarioMinimoDF ,
            NULL AS salatioMinimoRegion ,
            NULL AS eymArt25 ,
            NULL AS eymArt106ii ,
            NULL AS eymArt107 ,
            NULL AS ivArt147 ,
            NULL AS cvArt168ii ,
            NULL AS baseCalculo ,
            NULL AS grupo ,
            '' AS textogrupo ,
            @copias AS cuantosRecibos ,
            a.numero AS numeroRecibo ,
            a.numero AS recibo ,
            CASE WHEN ( a.serial = 20
                        OR a.serial = 40
                      )
                      AND @retiro = 0
                 THEN ( ISNULL(b.importe_p, 0) + ISNULL(b.importe_t, 0)
                        + ISNULL(b.intereses, 0) )
                 WHEN ( a.serial = 20
                        OR a.serial = 40
                      )
                      AND @retiro = 1 THEN ISNULL(b.retiros, 0)
                 ELSE NULL
            END AS percepcionesEmpleado ,
            CASE WHEN ( a.serial = 20
                        OR a.serial = 40
                      )
                      AND @retiro = 0
                 THEN ( ISNULL(b.adeudo, 0) + ISNULL(b.retiros, 0) )
                 ELSE NULL
            END AS deduccionesEmpleado ,
            CASE WHEN ( a.serial = 20
                        OR a.serial = 40
                      )
                      AND @retiro = 0
                 THEN ( ISNULL(b.importe_p, 0) + ISNULL(b.importe_t, 0)
                        + ISNULL(b.intereses, 0) ) - ( ISNULL(b.adeudo, 0)
                                                       + ISNULL(b.retiros, 0) )
                 WHEN ( a.serial = 20
                        OR a.serial = 40
                      )
                      AND @retiro = 1 THEN ISNULL(b.retiros, 0)
                 ELSE NULL
            END AS netoPagarEmpleado ,
            a.grupo AS grupoRecibo ,
            e.rfcalfa AS rfcAlfa ,
            e.rfcnum AS rfcNum ,
            e.rfchomo AS rfcHomo ,
            --ISNULL(ae.acu_cv, 0) AS acumuladoCv ,
            ISNULL(ae.acu_percep, 0) + b.importe_p + b.importe_t AS acumuladoPercepcion ,
            ISNULL(ae.gravable, 0) AS acumuladoPercepcionGtavable ,
            ISNULL(ae.ispt, 0) AS acumuladoISR ,
            ISNULL(ae.acu_info, 0) AS acumuladoInfonavit ,
            ISNULL(ae.acu_sar, 0) AS acumuladoSar ,
            e.mail AS Email,
            e.fchantigua AS fechaAntiguedad ,
            NULL AS esTotal
    FROM    @totalRows AS a
            INNER JOIN dbo.fondo_de_ahorros AS b ON a.empresa = b.empresa
                                                    AND a.codigo = b.codigo
            INNER JOIN dbo.empleados AS e ON b.empresa = e.empresa
                                             AND b.codigo = e.codigo
            INNER JOIN dbo.Llaves AS l ON e.empresa = l.empresa
                                          AND e.codigo = l.codigo
            LEFT JOIN dbo.supervisores AS su ON l.empresa = su.empresa
                                                AND l.supervisor = su.supervisor
            LEFT JOIN dbo.clases AS cl ON l.empresa = cl.empresa
                                          AND l.clase = cl.clase
            LEFT JOIN dbo.tabulador AS t ON l.empresa = t.empresa
                                            AND l.ocupacion = t.ocupacion
            LEFT JOIN dbo.bancos AS ba ON l.banco = ba.banco
            LEFT JOIN dbo.centros AS c ON l.centro = c.centro
                                          AND l.empresa = c.empresa
            LEFT JOIN dbo.empresas AS emp ON ( B.empresa = emp.empresa )
            LEFT JOIN dbo.acum_emps AS ae ON ( ae.codigo = b.codigo
                                               AND ae.empresa = b.empresa
                                               AND ae.ejercicio = emp.ayo_operacion
                                             )
    ORDER BY a.codigo ,
            a.grupo ,
            a.serial

	IF OBJECT_ID('dbo.tRws') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tRws
        END
        
        
GO


IF EXISTS ( SELECT
                name
            FROM
                sysobjects
            WHERE
                name = 'PortalPatronObtenDetalleRecibosFunU' AND
                type = 'P' ) 
    DROP PROCEDURE PortalPatronObtenDetalleRecibosFunU
GO

CREATE PROCEDURE PortalPatronObtenDetalleRecibosFunU
(
	@nomina udtName,
	@ao udtInteger,
	@periodo udtInteger,
	@codigo udtInteger,
	@tiponom udtInteger,
	@empresa udtInteger
)
	--WITH ENCRYPTION
	
AS
	SET NOCOUNT ON
	DECLARE @cCodigo udtName

	SET @cCodigo = STR(@codigo)


	IF @nomina = 'FDO' BEGIN
		EXEC dbo.Obten_PortalDetalleReciboAhorro @empresa, @codigo , 0
	END 
	ELSE BEGIN
		EXEC dbo.Fun_U_RecibosFijos @empresa,
									@periodo,
									@periodo,
									@ao,
									@nomina,
									@tiponom,
									@cCodigo,
									1
									
	END
							
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronTiempoExtraxEmpelado')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronTiempoExtraxEmpelado
GO


CREATE PROCEDURE dbo.Obten_PortalPatronTiempoExtraxEmpelado
    (
      @Tiponom udtInteger , 
      @Periodo udtInteger , 
      @Ao udtInteger , 
      @Mes udtName ,
      @nTipo udtInteger, 
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''

    IF @Tiponom > 0
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.tiponom = '
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @Periodo > 0
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END
    IF @Mes <> ''
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ''' + @Mes + ''''
         END        
    IF @Ao > 0
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@Ao)))
                 
        END

	IF @llave > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'b.llave = '
                + LTRIM(RTRIM(STR(@llave)))
                 
        END
        IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.num_conc in(10,11,12,13) '
       IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.nomina = ''ORD'' '
            
             
    SET @selectClause = 'SELECT	e.codigo,'
						+'RTRIM(e.ap_paterno) + '' '' + RTRIM(e.ap_materno) + '' '' + RTRIM(e.nombre) AS ''Nombre'','
						+'k.num_conc,'
						+'k.concepto,'
						+'k.horas,'
						+'LTRIM(STR(k.tiponom)) + '' '' + n.nomina AS ''Tipo de Nmina'','
						+'k.periodo,'
						+'k.mes, '
						+'k.IMPORTE, '
						+'convert(nvarchar(30),k.fch_inicio,103) as  fch_inicio '
						+ CASE WHEN @nTipo = 1 THEN ', '''' AS departamento ' ELSE ',RTRIM(LTRIM(c.centro)) + '' '' + RTRIM(LTRIM(c.nomdepto)) AS departamento ' END
    SET @fromClause = 'FROM dbo.kardex_anual AS k '
					 + CASE WHEN @nTipo = 1 THEN ' ' ELSE
							   'LEFT JOIN dbo.nomina1_anual AS nom ON k.empresa = nom.empresa AND k.codigo = nom.codigo AND k.periodo = nom.periodo AND k.ayo_operacion = nom.ayo_operacion AND k.tiponom = nom.tiponom '
							  +'INNER JOIN dbo.Llaves AS ll ON k.empresa = ll.empresa AND k.codigo = ll.codigo '
						      +'INNER JOIN dbo.centros AS c ON c.centro = ISNULL(nom.centro,ll.centro) AND k.empresa = c.empresa ' END 
					 +'INNER JOIN dbo.tmpAccesoPortalPatron as b on  k.empresa=b.empresa '
					 +'INNER JOIN dbo.empleados AS e ON k.empresa = e.empresa AND k.codigo = e.codigo '
					 +'INNER JOIN dbo.Nominas AS n ON k.empresa=n.empresa AND k.tiponom=n.tiponom '
    SET @groupByClause = '  '
    SET @orderByClause = ' ORDER BY ' + CASE WHEN @nTipo = 1 THEN ' ' ELSE 'RTRIM(LTRIM(c.centro)) + '' '' + RTRIM(LTRIM(c.nomdepto)), ' END + 'k.codigo'


    IF @debug = 0 
        BEGIN

            EXEC (@selectClause +
            @fromClause + 
            @whereClause +
            @groupByClause +
            @orderByClause)
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END 




GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronTiempoExtraAnual')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronTiempoExtraAnual
GO


CREATE PROCEDURE dbo.Obten_PortalPatronTiempoExtraAnual
(    
    @Tiponom udtInteger ,
    @Periodo udtInteger ,
    @Ao     udtInteger ,
    @nTipo udtInteger,
    @llave   udtLong
)

    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    
    
    
    IF @Tiponom > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.tiponom = '
                + LTRIM(RTRIM(STR(@Tiponom)))
                 
        END
        
    IF @Periodo > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.periodo = '
                + LTRIM(RTRIM(STR(@Periodo)))
                 
        END
        
    IF @Ao > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'a.ayo_operacion = '
                + LTRIM(RTRIM(STR(@Ao)))
                 
        END        
    
	IF @llave > 0 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'b.llave = '
                + LTRIM(RTRIM(STR(@llave)))
                 
        END
        IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
                SET @whereClause = @whereClause + 'a.num_conc in(10,11,12,13) '
        
        
        IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
                SET @whereClause = @whereClause + 'a.nomina = ''ORD'' '

set @selectClause =	 'SELECT tiponom as ''TipoNomina'','
							+'Periodo ,'
							+'Ao ,'
							+ CASE WHEN @nTipo = 1 THEN ' '''' as Departamento,' ELSE 'centro as ''Departamento'',' END 
							+'isnull([10],0) as '' Hrs.Lab.D.D.(10)'','
							+'isnull([11],0) as ''Tpo.ExtraNo.Int.(11)'','
							+'isnull([12],0) as '' Tpo.ExtraInt.(12)'','
							+'isnull([13],0) as ''Tpo.ExtraTriple(13)'','
							+'isnull([10],0) + isnull([11],0) + isnull([12],0) + isnull([13],0) as ''HrsxPeriodo'' '
					 +'FROM   ( SELECT    a.periodo ,'
										+'a.ayo_operacion AS ao ,'
										+'0 as tiponom,'
										+'Sum(ISNULL(a.horas, 0)) AS horas ,'
										+ CASE WHEN @nTipo = 1 THEN ' '''' AS centro,' ELSE 'RTRIM(LTRIM(ISNULL(n.centro,ll.centro))) +  '' '' + RTRIM(LTRIM(c.nomdepto)) AS centro,' END 
										+'a.num_conc '
							  +'FROM      dbo.kardex_anual AS a '
							  + CASE WHEN @nTipo = 1 THEN ' ' ELSE
							   'LEFT JOIN dbo.nomina1_anual AS n ON a.empresa = n.empresa AND a.codigo = n.codigo AND a.periodo = n.periodo AND a.ayo_operacion = n.ayo_operacion AND a.tiponom = n.tiponom '
							  +'INNER JOIN dbo.Llaves AS ll ON a.empresa = ll.empresa AND a.codigo = ll.codigo '
						      +'INNER JOIN dbo.centros AS c ON c.centro = ISNULL(n.centro,ll.centro) AND a.empresa = c.empresa ' END 
							  +'INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa '
							  + @whereClause
							  + ' GROUP BY '
							  + CASE WHEN @nTipo = 1 THEN ' ' ELSE 'RTRIM(LTRIM(ISNULL(n.centro,ll.centro))) +  '' '' + RTRIM(LTRIM(c.nomdepto)),' END 						      
							  + 'a.ayo_operacion,a.periodo,a.num_conc '
							+') AS kardex_anual PIVOT '
						+'( SUM(horas) FOR num_conc IN ( [10], [11], [12], [13] ) ) AS PivotTable '
					    +'order by ao,tiponom,periodo '
					    
					    
					    
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause )
        END
        
        
GO



IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronComparativo')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronComparativo
GO


CREATE PROCEDURE dbo.Obten_PortalPatronComparativo
    (	
      @Tiponom udtInteger ,
      @concepto1 udtInteger ,
      @concepto2 udtInteger ,
      @concepto3 udtInteger ,
      @concepto4 udtInteger ,
      @tipo udtInteger,
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 


    DECLARE @nomintaText udtName ,
        @periodo udtInteger ,
        @ao udtInteger
        
	DECLARE @periodos AS TABLE(empresa udtInteger,periodo udtInteger, ayo_operacion udtInteger,periodoAnt udtInteger, ayo_operacionAnt udtInteger)
		
    INSERT INTO @periodos
    SELECT  b.empresa,
			p.periodo ,
            p.ayo_operacion,
            ISNULL(CASE WHEN p.periodo=1 THEN (SELECT MAX(periodo) FROM dbo.Periodos WHERE empresa=p.empresa AND tiponom=p.tiponom AND ayo_operacion=p.ayo_operacion-1) ELSE p.periodo-1 end,0) ,
            CASE WHEN p.periodo=1 THEN p.ayo_operacion-1 ELSE p.ayo_operacion end
    FROM    dbo.Periodos AS p
    INNER JOIN dbo.tmpAccesoPortalPatron AS b ON p.empresa = b.empresa AND b.llave = @llave
    WHERE   p.tiponom = @tiponom
            AND p.estatus = 'A'
           
    SET @nomintaText = CASE WHEN @tiponom = 1 THEN 'SEM'
                            WHEN @tiponom = 2 THEN 'DEC'
                            WHEN @tiponom = 3 THEN 'CAT'
                            WHEN @tiponom = 4 THEN 'QNA'
                            WHEN @tiponom = 5 THEN 'MES'
                            WHEN @tiponom = 6 THEN 'ESP'
                       END 

    IF OBJECT_ID('dbo.tmp_DetalleActivo') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_DetalleActivo
        END
    IF OBJECT_ID('dbo.tmp_DetalleAnterior') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_DetalleAnterior
        END
        
    CREATE TABLE dbo.tmp_DetalleActivo
        (
          clave VARCHAR(15) ,
          nombre VARCHAR(50) ,
          importe NUMERIC(10, 2) ,
          tipo INT,
          tipoConc INT
        )

    CREATE TABLE dbo.tmp_DetalleAnterior
        (
          clave VARCHAR(15) ,
          nombre VARCHAR(50) ,
          importe NUMERIC(10, 2) ,
          tipo INT,
          tipoConc INT
        )
        
            IF @tipo = 1 BEGIN
				INSERT  INTO dbo.tmp_DetalleActivo
				( clave ,
				  nombre ,
				  importe ,
				  tipo
				)
				( SELECT    l.centro AS Clave ,
							c.nomdepto AS nombre ,
							SUM(CASE WHEN ( (k.num_conc >=1 and k.num_conc<=99) or ( k.num_conc >= 501 AND k.num_conc <= 599)OR ( k.num_conc >= 1101 AND k.num_conc <= 1199) ) THEN k.importe
									 ELSE 0
								END)
							- SUM(CASE WHEN( ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1099) )THEN k.importe
									   ELSE 0
								  END) AS importe ,
							1 AS tipo
				  FROM      dbo.kardex AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
							INNER JOIN dbo.centros AS c ON l.centro = c.centro
														   AND l.empresa = c.empresa
							AND k.nomina = @nomintaText
				  GROUP BY  l.centro ,
							c.nomdepto
				)
				UNION
				( SELECT    CAST(k.num_conc AS VARCHAR(15)) AS clave ,
							k.concepto AS nombre ,
							SUM(k.importe) AS importe ,
							2 AS tipo
				  FROM      dbo.kardex AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
				  WHERE     k.nomina = @nomintaText
							AND k.num_conc IN ( @concepto1, @concepto2, @concepto3,
												@concepto4 )
				  GROUP BY  k.num_conc ,
							k.concepto
				)
				ORDER BY tipo ,
						clave
				INSERT  INTO dbo.tmp_DetalleAnterior
				( clave ,
				  nombre ,
				  importe ,
				  tipo
				)
				( SELECT    l.centro AS Clave ,
							c.nomdepto AS nombre ,
							SUM(CASE WHEN ( (k.num_conc >=1 and k.num_conc<=99) or ( k.num_conc >= 501 AND k.num_conc <= 599)OR ( k.num_conc >= 1101 AND k.num_conc <= 1199) ) THEN k.importe
									 ELSE 0
								END)
							- SUM(CASE WHEN( ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1099) )THEN k.importe
									   ELSE 0
								  END) AS importe ,
							1 AS tipo
				  FROM      dbo.kardex_anual AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
							INNER JOIN dbo.centros AS c ON l.centro = c.centro
														   AND l.empresa = c.empresa
				  INNER JOIN @periodos AS p ON k.empresa=p.empresa AND k.periodo=p.periodoAnt AND k.ayo_operacion=p.ayo_operacionAnt
				  WHERE     k.nomina = 'ORD'
							AND k.tiponom = @tiponom
							--AND k.num_conc <= 199
				  GROUP BY  l.centro ,
							c.nomdepto
				)
				UNION
				( SELECT    CAST(k.num_conc AS VARCHAR(15)) AS clave ,
							k.concepto AS nombre ,
							SUM(k.importe) AS importe ,
							2 AS tipo
				  FROM      dbo.kardex_anual AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
				  INNER JOIN @periodos AS p ON k.empresa=p.empresa AND k.periodo=p.periodoAnt AND k.ayo_operacion=p.ayo_operacionAnt
				  WHERE     k.nomina = 'ORD'
							AND k.ayo_operacion = @ao
							AND k.num_conc IN ( @concepto1, @concepto2, @concepto3,
												@concepto4 )
				  GROUP BY  k.num_conc ,
							k.concepto
				)
				ORDER BY tipo ,
						clave	
        END ELSE BEGIN
			INSERT  INTO dbo.tmp_DetalleActivo
				( clave ,
				  nombre ,
				  importe ,
				  tipo,
				  tipoConc
				)
			SELECT    k.num_conc AS Clave ,
							MAX(k.concepto) AS nombre ,
							SUM(k.importe) AS importe ,
							1 AS tipo,
							CASE WHEN ( (k.num_conc >=1 and k.num_conc<=99) or ( k.num_conc >= 501 AND k.num_conc <= 599)OR ( k.num_conc >= 1101 AND k.num_conc <= 1199) ) THEN 1 
							     WHEN ( ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1099) ) THEN 2 ELSE 3 END 
				  FROM      dbo.kardex AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
							INNER JOIN dbo.centros AS c ON l.centro = c.centro
														   AND l.empresa = c.empresa
							AND k.nomina = @nomintaText
				GROUP BY  k.num_conc
				INSERT  INTO dbo.tmp_DetalleAnterior
				( clave ,
				  nombre ,
				  importe ,
				  tipo,
				  TipoConc
				)
				( SELECT    k.num_conc AS Clave ,
							MAX(k.concepto) AS nombre ,
							SUM(k.importe) AS importe ,
							1 AS tipo,
							CASE WHEN ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) THEN 1 WHEN ( k.num_conc >= 1001 AND k.num_conc <= 1099) THEN 2 ELSE 3 END 
				  FROM      dbo.kardex_anual AS k
				  INNER JOIN dbo.tmpAccesoPortalPatron AS b ON k.empresa = b.empresa AND b.llave = @llave
							INNER JOIN dbo.Llaves AS l ON k.empresa = l.empresa
														  AND k.codigo = l.codigo
							INNER JOIN dbo.centros AS c ON l.centro = c.centro
														   AND l.empresa = c.empresa
				  INNER JOIN @periodos AS p ON k.empresa=p.empresa AND k.periodo=p.periodoAnt AND k.ayo_operacion=p.ayo_operacionAnt
				  WHERE     k.nomina = 'ORD'
							AND k.tiponom = @tiponom
							--AND k.num_conc <= 199
				  GROUP BY  k.num_conc
				)
        END
        

DELETE tmp_DetalleActivo WHERE importe<=0
DELETE tmp_DetalleAnterior WHERE importe<=0

    SELECT clave AS Clave ,
           nombre AS Nombre,
           Actual,
           Anterior,
           Diferencia
    FROM(
			SELECT  ISNULL(a.clave, b.clave) AS clave ,
					ISNULL(a.nombre, b.nombre) AS nombre ,
					ISNULL(a.importe, 0) AS 'Actual' ,
					ISNULL(b.importe, 0) AS 'Anterior' ,
					ISNULL(a.importe, 0) - ISNULL(b.importe, 0) AS 'Diferencia' ,
					ISNULL(a.tipo, b.tipo) AS tipo,
					1 AS TipoRes,
					ISNULL(a.tipoconc,b.tipoconc) AS tipoconc
			FROM    dbo.tmp_DetalleActivo AS a
					FULL OUTER JOIN dbo.tmp_DetalleAnterior AS b ON a.clave = b.clave
																	AND a.tipo = b.tipo
			UNION
			SELECT 0 AS clave ,
					'TOTAL GENERAL' AS nombre ,
					SUM(ISNULL(a.importe, 0)) AS 'Actual' ,
					SUM(ISNULL(b.importe, 0)) AS 'Anterior' ,
					SUM(ISNULL(a.importe, 0) - ISNULL(b.importe, 0)) AS 'Diferencia' ,
					99 AS tipo,
					2 AS TipoRes,            
					4 AS tipoconc
			FROM    dbo.tmp_DetalleActivo AS a
					FULL OUTER JOIN dbo.tmp_DetalleAnterior AS b ON a.clave = b.clave
																	AND a.tipo = b.tipo
			
	) AS tbl
	ORDER BY TipoRes,tipoconc,clave

    IF OBJECT_ID('dbo.tmp_DetalleActivo') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_DetalleActivo
        END
    IF OBJECT_ID('dbo.tmp_DetalleAnterior') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_DetalleAnterior
        END

GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronUltimaMS')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronUltimaMS
GO


CREATE PROCEDURE dbo.Obten_PortalPatronUltimaMS
    (	
    @tiponom udtInteger,
	@ayo_operacion udtInteger,
	@llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 



		
		
	SET NOCOUNT ON
	
DECLARE @Movs TABLE
    (
      empresa INT ,
      codigo BIGINT ,
      mov VARCHAR(2) ,
      fecha DATETIME,
      centro VARCHAR(60)
    )

INSERT  INTO @Movs
        ( empresa ,
          codigo ,
          mov ,
          fecha,
          centro 
        )
        SELECT  a.empresa ,
                a.codigo ,
                a.mov ,
                MAX(a.fch_mov) AS fecha,
                RTRIM(LTRIM(m.centro)) + ' ' + RTRIM(LTRIM(m.nomdepto)) AS centro
        FROM    dbo.avisos_imss AS a
        INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa AND b.llave=@llave
        INNER JOIN dbo.empleados AS e ON a.empresa = e.empresa
                                         AND a.codigo = e.codigo
		INNER JOIN dbo.Llaves AS l ON e.empresa = l.empresa AND e.codigo = l.codigo
		INNER JOIN dbo.centros AS m ON l.centro = m.centro AND l.empresa = m.empresa
                                                 
        WHERE   a.mov = 'MS'
                AND (a.origen <> 'VA' AND a.origen <> 'V' AND a.origen<>'AR')
                AND a.ayo_operacion=@ayo_operacion
                AND l.tiponom=@tiponom
        GROUP BY a.empresa ,
                a.codigo ,
                a.mov,
                RTRIM(LTRIM(m.centro)) + ' ' + RTRIM(LTRIM(m.nomdepto))
        ORDER BY a.empresa ,
                a.codigo

SELECT  a.empresa AS Empresa,
        a.codigo AS Codigo,
        RTRIM(b.ap_paterno) + ' ' + RTRIM(b.ap_materno) + ' ' + RTRIM(b.nombre) AS Nombre ,
        CONVERT(NVARCHAR(15),b.fchalta,103) AS Alta ,
        c.sueldo AS Sueldo,
        CONVERT(NVARCHAR(15),a.fecha,103) AS Fecha,
		cc.centro,
		c.sueldoant,
		cc.nomdepto,
		t.actividad,
		p.nombre AS supervisor
FROM    @Movs AS a
        INNER JOIN dbo.empleados AS b ON a.empresa = b.empresa
                                         AND a.codigo = b.codigo
		INNER JOIN dbo.Llaves AS l ON b.empresa = l.empresa AND b.codigo = l.codigo
		INNER JOIN dbo.supervisores AS p ON l.empresa = p.empresa AND l.supervisor = p.supervisor
		INNER JOIN dbo.tabulador AS t ON l.empresa = t.empresa AND l.ocupacion = t.ocupacion
		INNER JOIN dbo.centros AS cc ON l.centro = cc.centro AND l.empresa = cc.empresa
		INNER JOIN dbo.avisos_imss AS c ON a.empresa = c.empresa
                                           AND a.codigo = c.codigo
                                           AND a.fecha = c.fch_mov
                                           AND a.mov = c.mov
                                          -- AND c.origen <> 'VA'
                                           


GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronTiposNomina')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronTiposNomina

GO

CREATE PROCEDURE dbo.Obten_PortalPatronTiposNomina ( @llave udtLong )
    WITH ENCRYPTION
AS 
	SET NOCOUNT ON 
	
    ( SELECT    '00 TODAS' AS nomina
    )
    UNION
    ( SELECT DISTINCT
                '0' + RTRIM(LTRIM(STR(a.tiponom))) + ' '
                + RTRIM(LTRIM(d.nomina))
      FROM      dbo.Llaves AS a
                INNER JOIN dbo.Nominas AS d ON a.empresa = d.empresa
                                               AND a.tiponom = d.tiponom
                INNER JOIN dbo.empleados AS b ON a.empresa = b.empresa
                                                 AND a.codigo = b.codigo
                INNER JOIN dbo.tmpAccesoPortalPatron AS c ON b.empresa = c.empresa
      WHERE     b.activo = 'S'
    )

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronHistoricoMovimientos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronHistoricoMovimientos

GO

CREATE PROCEDURE dbo.Obten_PortalPatronHistoricoMovimientos
    (
      @Inicio udtDateTime,
      @Termino udtDateTime,
      @Movimiento udtInteger,
      @SoloCambios udtInteger,
      @tiponom udtInteger,
      @tipoemp udtInteger,
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT DMY

    DECLARE @SQl AS VARCHAR(8000) ,
        @WHERE AS VARCHAR(1024)
    SET @WHERE = CASE WHEN @Movimiento = 1
                      THEN 'in(''A'',''B'',''MS'',''RI'')'
                      WHEN @Movimiento = 2 THEN 'in(''A'')'
                      WHEN @Movimiento = 3 THEN 'in(''B'')'
                      WHEN @Movimiento = 4 THEN 'in(''MS'')'
                      WHEN @Movimiento = 5 THEN 'in(''RI'')'
                 END 
	--PRINT @WHERE
    SET @SQl = 'SELECT	convert(nvarchar(30),avisos_imss.fch_mov,103) AS FECHA,'
        + 'rtrim(ltrim(str(empleados.codigo))) as codigo,rtrim(empleados.nombre) + SPACE(1) + rtrim(empleados.ap_paterno) + SPACE(1) + rtrim(empleados.ap_materno) AS NOMBRE,'
        + 'avisos_imss.mov, avisos_imss.sueldo,avisos_imss.saldiaint, '
        +'case when avisos_imss.mov=''MS'' then rtrim(ltrim(convert(varchar(30), isnull(avisos_imss.sueldoant,0) ))) else '''' end as sueldoAnt ,'
        +'case when avisos_imss.mov=''B'' then avisos_imss.mot_baja else '''' end as movBaja,'
        + 'avisos_imss.diastr,isnull(avisos_imss.ausen,0) as ausen,isnull(avisos_imss.incap,0) as incap,'
        +'case when avisos_imss.mov=''MS'' then rtrim(ltrim(convert(varchar(30), isnull(avisos_imss.saldiaintant,0) ))) else '''' end as saldiaintant, '
        +'rtrim(ltrim(tabulador.ocupacion)) as ocupacion, '
        +'rtrim(ltrim(tabulador.actividad)) as actividad '
        + 'FROM avisos_imss avisos_imss '
        + 'LEFT JOIN dbo.OrigenAvisoImss OrigenAvisoImss ON avisos_imss.origen = OrigenAvisoImss.origen '
        + 'INNER JOIN dbo.tmpAccesoPortalPatron AS b ON avisos_imss.empresa = b.empresa AND b.llave='+ LTRIM(RTRIM(STR(@llave)))
        + 'INNER JOIN empleados empleados ON avisos_imss.empresa = empleados.empresa AND avisos_imss.codigo = empleados.codigo '
        + 'INNER JOIN dbo.Llaves llaves ON empleados.empresa = llaves.empresa AND empleados.codigo = llaves.codigo '
        + 'INNER JOIN dbo.Tabulador Tabulador ON Tabulador.empresa = llaves.empresa AND Tabulador.ocupacion = llaves.ocupacion '
        + 'INNER JOIN empresas empresas ON avisos_imss.empresa = empresas.empresa '
        + 'WHERE mov ' + @WHERE + ' and (avisos_imss.fch_mov>='''
        + CAST(@Inicio AS VARCHAR) + ''' and avisos_imss.fch_mov <='''
        + CAST(@Termino AS VARCHAR) + ''') '
        + CASE WHEN @SoloCambios = 1 THEN ' AND OrigenAvisoImss.funcion in(''D'',''M'',''N'') ' ELSE ' ' END 
        + CASE WHEN @tiponom > 0 THEN ' AND llaves.tiponom = ' + LTRIM(RTRIM(STR(@tiponom))) ELSE '' END
        + CASE WHEN @tipoemp > 1 THEN ' AND empleados.sindicato =''' + CASE WHEN @tipoemp = 2 THEN 'S' ELSE 'C' END + '''' ELSE '' END
        + ' ORDER BY avisos_imss.fch_mov, empleados.codigo'
    EXEC(@SQl)
    --PRINT(@SQl)
    
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronPoliza')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronPoliza

GO


CREATE PROCEDURE dbo.Obten_PortalPatronPoliza
    (
      @tiponom udtInteger ,
      @periodo udtInteger ,
      @ayo_operacion udtInteger ,
      @mes udtName ,
      @nominas udtName,
      @nTipo udtInteger,
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''
    IF OBJECT_ID('dbo.tRws') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tRws
        END
        
    CREATE TABLE dbo.tRws ( empresa INT, serial INT )

    DECLARE @counter INT
    
    SET @counter = 1 

    WHILE @counter <= 100
        BEGIN	
            INSERT  INTO dbo.tRws
                    ( empresa, serial )
                    SELECT  0 AS empresa ,
                            @counter
            --FROM empresas
            SET @counter = @counter + 1
        END

    DECLARE @kardex TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(10, 2)
        )
    DECLARE @SQL udtStringSize8000
	
    SET @SQL = 'SELECT 0 AS empresa ,' + 'isnull(l.centro,ll.centro) as centro , ' + 'k.num_conc , '
        + 'min(k.concepto) , ' + 'SUM(k.importe) '
        + 'FROM   dbo.kardex_anual AS k '
        + 'INNER JOIN dbo.llaves AS ll ON k.empresa = ll.empresa AND k.codigo = ll.codigo '
        + 'LEFT JOIN dbo.nomina1_anual AS l ON k.empresa = l.empresa AND k.codigo = l.codigo AND k.periodo = l.periodo AND k.ayo_operacion = l.ayo_operacion and l.tiponom=k.tiponom and k.nomina=l.nomina '
        + 'INNER JOIN dbo.tmpAccesoPortalPatron AS emp ON k.empresa = emp.empresa AND emp.llave= ' + RTRIM(LTRIM(STR(@llave)))
        + ' WHERE	k.ayo_operacion = ' + LTRIM(STR(@ayo_operacion))
        + iif(@tiponom>0,' AND k.tiponom = ' + RTRIM(STR(@tiponom)) ,'')
        + ' AND k.nomina in(' + @nominas + ')' 
        + CASE WHEN @periodo > 0
               THEN ' AND k.periodo= ' + RTRIM(STR(@periodo))
               ELSE ''
          END + CASE WHEN @mes <> '' THEN ' AND k.mes= ''' + @mes + ''''
                     ELSE ''
                END 
        + 'GROUP BY isnull(l.centro,ll.centro) , ' + 'k.num_conc ' 
        + 'ORDER BY isnull(l.centro,ll.centro) , ' + 'k.num_conc ' 
	IF @nTipo = 2
	BEGIN
		INSERT  INTO @kardex
				( empresa ,
				  centro ,
				  num_conc ,
				  concepto ,
				  importe
		        
				)
				EXEC ( @SQL
					)
	END
	 --EXEC ( @SQL
  --              )
    SET @SQL = 'SELECT 0 AS empresa ,' + '''999999999999997'' , '
        + 'k.num_conc , ' + 'MIN(k.concepto) , ' + 'SUM(k.importe) '
        + 'FROM   dbo.kardex_anual AS k ' 
        + 'INNER JOIN dbo.tmpAccesoPortalPatron AS emp ON K.empresa = emp.empresa AND emp.llave= ' + RTRIM(LTRIM(STR(@llave)))
        + 'WHERE	k.ayo_operacion = '
        + LTRIM(STR(@ayo_operacion)) 
		+ iif(@Tiponom>0,' AND k.tiponom = '+ RTRIM(STR(@tiponom)) ,'')
		+ ' AND k.nomina in(' + @nominas + ')'  
        + CASE WHEN @periodo > 0
               THEN ' AND k.periodo= ' + RTRIM(STR(@periodo))
               ELSE ''
          END + CASE WHEN @mes <> '' THEN ' AND k.mes= ''' + @mes + ''''
                     ELSE ''
                END + 'GROUP BY k.num_conc  ' 
	
    INSERT  INTO @kardex
            ( empresa ,
              centro ,
              num_conc ,
              concepto ,
              importe
	        
            )
            EXEC ( @SQL
                )
	
	
    DECLARE @percepciones TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(10, 2) ,
          serial BIGINT
        ) 
    
    INSERT  INTO @percepciones
            ( empresa ,
              centro ,
              num_conc ,
              concepto ,
              importe ,
              serial
            )
            SELECT  empresa ,
                    centro ,
                    num_conc ,
                    concepto ,
                    SUM(importe) AS importe ,
                    dense_rank() OVER ( PARTITION  BY centro ORDER BY centro, num_conc, concepto ) serial
            FROM    @kardex
            WHERE   ( ( num_conc >= 1
                        AND num_conc <= 99
                      )
                      OR ( num_conc >= 501
                           AND num_conc <= 599
                         )
                      OR ( num_conc >= 1100
                           AND num_conc <= 1199
                         )
                    )
            GROUP BY empresa ,
                    centro ,
                    num_conc ,
                    concepto
            ORDER BY empresa ,
                    centro ,
                    num_conc
    
    DECLARE @deducciones TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(10, 2) ,
          serial BIGINT
        ) 
    
    INSERT  INTO @deducciones
            ( empresa ,
              centro ,
              num_conc ,
              concepto ,
              importe ,
              serial
            )
            SELECT  empresa ,
                    centro ,
                    num_conc ,
                    concepto ,
                    SUM(importe) AS importe ,
                    dense_rank() OVER ( PARTITION  BY centro ORDER BY centro, num_conc, concepto ) serial
            FROM    @kardex
            WHERE   ( ( num_conc >= 101
                        AND num_conc <= 200
                      )
                      OR ( num_conc >= 601
                           AND num_conc <= 699
                         )
                      OR ( num_conc >= 1001
                           AND num_conc <= 1099
                         )
                    )
            GROUP BY empresa ,
                    centro ,
                    num_conc ,
                    concepto
            ORDER BY empresa ,
                    centro ,
                    num_conc
    
    DECLARE @provisiones TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(10, 2) ,
          serial BIGINT
        ) 
    
    INSERT  INTO @provisiones
            ( empresa ,
              centro ,
              num_conc ,
              concepto ,
              importe ,
              serial
            )
            SELECT  empresa ,
                    centro ,
                    num_conc ,
                    concepto ,
                    SUM(importe) AS importe ,
                    dense_rank() OVER ( PARTITION  BY centro ORDER BY centro, num_conc, concepto ) serial
            FROM    @kardex
            WHERE   ( (num_conc >= 201
                      AND num_conc <= 299)
                    )
            GROUP BY empresa ,
                    centro ,
                    num_conc ,
                    concepto
            ORDER BY empresa ,
                    centro ,
                    num_conc

    DECLARE @totalRows TABLE
        (
          empresa INT ,
          centro VARCHAR(15) ,
          nombre VARCHAR(60) ,
          num_conc_p INT ,
          concepto_p VARCHAR(35) ,
          importe_p NUMERIC(10, 2) ,
          num_conc_d INT ,
          concepto_d VARCHAR(35) ,
          importe_d NUMERIC(10, 2) ,
          num_conc_pv INT ,
          concepto_pv VARCHAR(35) ,
          importe_pv NUMERIC(10, 2) ,
          percepciones NUMERIC(10, 2) ,
          deducciones NUMERIC(10, 2) ,
          provisiones NUMERIC(10, 2) ,
          neto NUMERIC(10, 2) ,
          serial INT
        )

	
    INSERT  INTO @totalRows
            ( empresa ,
              centro ,
              nombre ,
              serial ,
              percepciones ,
              deducciones ,
              provisiones ,
              neto
            )
            SELECT  k.empresa ,
                    k.centro ,
                    max(c.nomdepto) as nomdepto ,
                    b.serial ,
                    ( SELECT    SUM(importe)
                      FROM      @percepciones
                      WHERE     centro = k.centro
                    ) ,
                    ( SELECT    SUM(importe)
                      FROM      @deducciones
                      WHERE     centro = k.centro
                    ) ,
                    ( SELECT    SUM(importe)
                      FROM      @provisiones
                      WHERE     centro = k.centro
                    ) ,
                    ( ( SELECT  SUM(importe)
                        FROM    @percepciones
                        WHERE   centro = k.centro
                      ) - ( SELECT  SUM(importe)
                            FROM    @deducciones
                            WHERE   centro = k.centro
                          ) )
            FROM    @kardex AS k
                    LEFT JOIN dbo.centros AS c ON k.centro = c.centro
                    INNER JOIN dbo.tRws AS b ON b.empresa = k.empresa
            GROUP BY k.empresa ,
                    k.centro ,
                    --c.nomdepto ,
                    b.serial
	
	
    UPDATE  a
    SET     num_conc_p = b.num_conc ,
            concepto_p = b.concepto ,
            importe_p = b.importe
    FROM    @totalRows AS a
            INNER JOIN @percepciones AS b ON a.empresa = b.empresa
                                             AND a.centro = b.centro
                                             AND a.serial = b.serial
	
    UPDATE  a
    SET     num_conc_d = b.num_conc ,
            concepto_d = b.concepto ,
            importe_d = b.importe
    FROM    @totalRows AS a
            INNER JOIN @deducciones AS b ON a.empresa = b.empresa
                                            AND a.centro = b.centro
                                            AND a.serial = b.serial
	
	
    UPDATE  a
    SET     num_conc_pv = b.num_conc ,
            concepto_pv = b.concepto ,
            importe_pv = b.importe
    FROM    @totalRows AS a
            INNER JOIN @provisiones AS b ON a.empresa = b.empresa
                                            AND a.centro = b.centro
                                            AND a.serial = b.serial
	
    UPDATE  @totalRows
    SET     nombre = 'TOTAL GENERAL'
    WHERE   centro = '999999999999997'
	
    DELETE  @totalRows
    WHERE   num_conc_p IS NULL
            AND num_conc_d IS NULL
            AND num_conc_pv IS NULL
	
    SELECT  *
    FROM    @totalRows
    ORDER BY centro ,
            serial


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronSabanaxCentros')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronSabanaxCentros
GO


CREATE PROCEDURE dbo.Obten_PortalPatronSabanaxCentros
    (
      @Tiponom udtInteger ,
      @Periodo udtInteger , -- puede quedar en cero si @TipoReporte = 'PA'
      @Ao udtInteger , -- puede quedar en cero si @TipoReporte = 'PA'
      @Mes udtName , -- puede quedar en cero si @TipoReporte <> 'PA'
      @TipoReporte udtName, -- 'PA' periodo activo -- 'MES' mensual -- 'PER' periodo cerrado
      @nominas udtStringSize1024,
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''

    DECLARE @nominaText udtName
	
	IF OBJECT_ID('dbo.tmp_Detalle_SABANA') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_Detalle_SABANA
        END
    IF OBJECT_ID('dbo.tmp_centros_SABANA') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_centros_SABANA
        END
    IF OBJECT_ID('dbo.tmp_KADetalle') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_KADetalle
        END
	CREATE TABLE dbo.tmp_KADetalle
        (
          empresa int,
		  codigo int,
		  num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(12, 2) ,
          centro VARCHAR(60) ,
          tipo_conc INT,
          trabajadores udtLong
        )
	CREATE TABLE dbo.tmp_Detalle_SABANA
        (
          num_conc INT ,
          concepto VARCHAR(35) ,
          importe NUMERIC(12, 2) ,
          centro VARCHAR(60) ,
          tipo_conc INT,
          trabajadores udtLong
        )
    CREATE TABLE dbo.tmp_centros_SABANA
        (
          centro VARCHAR(60) ,
          serial BIGINT
        )


    IF @Tiponom > 0
         
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + CASE WHEN @TipoReporte = 'PER' THEN 'l.tiponom = ' ELSE  'k.tiponom = ' END 
                + LTRIM(RTRIM(STR(@tiponom)))
                 
        END
    IF @Periodo > 0
        AND @TipoReporte = 'PER' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.periodo = '
                + LTRIM(RTRIM(STR(@periodo)))
                 
        END
    IF @Mes <> ''
        AND @TipoReporte = 'MES' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.mes = ''' + @Mes  + ''''
                 
        END
    IF @Ao > 0
        AND @TipoReporte <> 'PA' 
        BEGIN
    
            IF @whereClauseUsed = 0 
                BEGIN
	       
                    SET @whereClause = @whereClause + 'WHERE '
                    SET @whereClauseUsed = 1

                END
            ELSE 
                SET @whereClause = @whereClause + ' AND '
	                 
            SET @whereClause = @whereClause + 'k.ayo_operacion = '
                + LTRIM(RTRIM(STR(@Ao)))
                 
        END
    IF @TipoReporte = 'PA' 
        BEGIN
            SET @nominaText = CASE WHEN @Tiponom = 1 THEN 'SEM'
                                   WHEN @Tiponom = 2 THEN 'DEC'
                                   WHEN @Tiponom = 3 THEN 'CAT'
                                   WHEN @Tiponom = 4 THEN 'QNA'
                                   WHEN @Tiponom = 5 THEN 'MES'
                                   WHEN @Tiponom = 6 THEN 'ESP'
                              END	
        END
    ELSE 
        SET @nominaText = 'ORD'
		
	
    IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
	                 
    SET @whereClause = @whereClause + 'k.nomina in( ' + @nominas  
        + ') '

		IF @whereClauseUsed = 0 
        BEGIN
	       
            SET @whereClause = @whereClause + 'WHERE '
            SET @whereClauseUsed = 1

        END
    ELSE 
        SET @whereClause = @whereClause + ' AND '
	                 
    SET @whereClause = @whereClause + ' k.empresa in(select emp.empresa from dbo.tmpAccesoPortalPatron AS emp where emp.llave='+LTRIM(RTRIM(str(@llave)))+' ) '
                 
	
	--Inserta Kardex
	
    SET @selectClause = 'INSERT INTO dbo.tmp_KADetalle ( empresa, codigo, num_conc, concepto, importe, centro , tipo_conc ) '
        + 'SELECT k.empresa,k.codigo, k.num_conc AS ''Concepto'','
        + 'k.concepto AS ''Nombre del Concepto'','
        + 'SUM(k.importe) AS ''Importe'','
        + 'RTRIM(ISNULL(l.centro,b.centro)) + '' '' + RTRIM(c.nomdepto) AS ''Departamento'','
        + 'CASE WHEN (( (k.num_conc >=1 and k.num_conc<=99) or ( k.num_conc >= 501 AND k.num_conc <= 599)OR ( k.num_conc >= 1101 AND k.num_conc <= 1199) )) THEN 1 '
		+' WHEN (( ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1099) )) THEN 2 '
		+' WHEN (k.num_conc>=201 and k.num_conc<=299) THEN 3 ELSE 0 END as tipo_conc '
					
    SET @fromClause = 'FROM '
        + CASE WHEN @TipoReporte = 'PA' THEN ' dbo.kardex '
               ELSE ' dbo.kardex_anual '
          END + ' AS k '
        + ' INNER JOIN dbo.Llaves AS b ON k.empresa = b.empresa AND k.codigo = b.codigo '
        + ' LEFT JOIN dbo.nomina1_anual AS l ON k.empresa = l.empresa AND k.codigo = l.codigo AND k.ayo_operacion = l.ayo_operacion '
        + ' AND k.periodo = l.periodo AND k.nomina = l.nomina AND k.tiponom = l.tiponom '
        + ' INNER JOIN centros AS c ON ISNULL(l.centro,b.centro) = c.centro AND b.empresa = c.empresa '
    SET @groupByClause = ' GROUP BY k.empresa,k.codigo,ISNULL(l.centro,b.centro),c.nomdepto,k.num_conc ,k.concepto '
    SET @orderByClause = ' ORDER BY k.empresa,k.codigo,k.num_conc '


    IF @debug =0
        BEGIN

            exec (@selectClause +
            @fromClause + 
            @whereClause +
            @groupByClause +
            @orderByClause)
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END 
Print '1'
	--Inserta Detalle de Conceptos
	
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + 'SELECT k.num_conc AS ''Concepto'','
        + 'k.concepto AS ''Nombre del Concepto'','
        + 'SUM(k.importe) AS ''Importe'','
        + 'k.centro  AS ''Departamento'','
        + 'CASE WHEN (( (k.num_conc >=1 and k.num_conc<=99) or ( k.num_conc >= 501 AND k.num_conc <= 599)OR ( k.num_conc >= 1101 AND k.num_conc <= 1199) )) THEN 1 '
		+' WHEN (( ( k.num_conc >= 101 AND k.num_conc <= 199) OR ( k.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1099) )) THEN 2 '
		+' WHEN (k.num_conc>=201 and k.num_conc<=299) THEN 3 ELSE 0 END as tipo_conc '
					
    SET @fromClause = 'FROM tmp_KADetalle as k '
	set @groupByClause  = ' group by k.num_conc,k.tipo_conc,k.concepto,k.centro '
	set @orderByClause = ' order by k.centro, k.tipo_conc,k.num_conc '
	



    IF @debug = 0
        BEGIN

            EXEC (@selectClause +
            @fromClause + @groupByClause + @orderByClause)
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause + @fromClause + @groupByClause + @orderByClause)
        END 
Print '2'
	--Inserta Totales Empleados
	
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + 'SELECT 999999 AS ''Concepto'','
        + ' ''TOTAL EMPLEADOS'' AS ''Nombre del Concepto'','
        + 'COUNT(DISTINCT(k.codigo)) AS ''Importe'','
        + 'k.centro AS ''Departamento'','
        + '4 as tipo_conc '
					
    SET @fromClause = 'FROM dbo.tmp_KADetalle  AS k '
	set @groupByClause  = ' group by k.centro '
	set @orderByClause = ' order by k.centro '


    IF @debug = 0
        BEGIN

            EXEC (@selectClause +
            @fromClause + @groupByClause + @orderByClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause + @fromClause + @groupByClause + @orderByClause )
        END 
Print '3'
    --Inserta Totales Percepciones
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT 999999 AS ''Concepto'','
        + ' ''TOTAL PERCEPCIONES'' AS ''Nombre del Concepto'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + 'k.centro AS ''Departamento'','
        + '1 as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 1 '
		+ ' GROUP BY k.num_conc,k.centro)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''PERCEPCIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '1 as tipo_conc) '

    IF @debug = 0
        BEGIN

            EXEC (@selectClause)
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause)
        END
Print '4'        
    --Inserta Totales Deducciones
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT 999999 AS ''Concepto'','
        + ' ''TOTAL DEDUCCIONES'' AS ''Nombre del Concepto'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + 'k.centro AS ''Departamento'','
        + '2 as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 2 '
		+ ' GROUP BY k.num_conc,k.centro)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''DEDUCCIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '2 as tipo_conc) '

    IF @debug = 0 
        BEGIN

            EXEC (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
Print '5'    
    --Inserta Totales PROVISIONES
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT 999999 AS ''Concepto'','
        + ' ''TOTAL PROVISIONES'' AS ''Nombre del Concepto'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + 'k.centro AS ''Departamento'','
        + '3 as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 3 '
		+ ' GROUP BY k.num_conc,k.centro)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''PROVISIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '3 as tipo_conc) '
        
        

    IF @debug = 0 
        BEGIN

            EXEC (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
    
   Print '6'
        
    DECLARE @totalRows udtLong
    DECLARE @centrosString udtStringSize8000
    DECLARE @centrosString2 udtStringSize8000
    
    DECLARE @centrosString_2 udtStringSize8000
    DECLARE @centrosString2_2 udtStringSize8000

	DECLARE @centrosString_3 udtStringSize8000
    DECLARE @centrosString3_3 udtStringSize8000

	DECLARE @centrosString_4 udtStringSize8000
    DECLARE @centrosString4_4 udtStringSize8000

	DECLARE @centrosString_5 udtStringSize8000
    DECLARE @centrosString5_5 udtStringSize8000

	DECLARE @centrosString_6 udtStringSize8000
    DECLARE @centrosString6_6 udtStringSize8000
    
	
	DECLARE @centrosString_7 udtStringSize8000
    DECLARE @centrosString7_7 udtStringSize8000

	DECLARE @centrosString_8 udtStringSize8000
    DECLARE @centrosString8_8 udtStringSize8000

	DECLARE @centrosString_9 udtStringSize8000
    DECLARE @centrosString9_9 udtStringSize8000

	DECLARE @centrosString_10 udtStringSize8000
    DECLARE @centrosString10_10 udtStringSize8000

	DECLARE @centrosString_11 udtStringSize8000
    DECLARE @centrosString11_11 udtStringSize8000

	DECLARE @centrosString_12 udtStringSize8000
    DECLARE @centrosString12_12 udtStringSize8000

	DECLARE @centrosString_13 udtStringSize8000
    DECLARE @centrosString13_13 udtStringSize8000

	DECLARE @centrosString_14 udtStringSize8000
    DECLARE @centrosString14_14 udtStringSize8000

	DECLARE @centrosString_15 udtStringSize8000
    DECLARE @centrosString15_15 udtStringSize8000

	DECLARE @centrosString_16 udtStringSize8000
    DECLARE @centrosString16_16 udtStringSize8000

	DECLARE @centrosString_17 udtStringSize8000
    DECLARE @centrosString17_17 udtStringSize8000

	DECLARE @centrosString_18 udtStringSize8000
    DECLARE @centrosString18_18 udtStringSize8000

	DECLARE @centrosString_19 udtStringSize8000
    DECLARE @centrosString19_19 udtStringSize8000

	DECLARE @centrosString_20 udtStringSize8000
    DECLARE @centrosString20_20 udtStringSize8000

    
    DECLARE @counter udtInteger

    SET @counter = 1 
    SET @centrosString = ''
    SET @centrosString2 = ''
    SET @centrosString_2 = ''
    SET @centrosString2_2 = ''
	SET @centrosString_3 = ''
    SET @centrosString3_3 = ''
	SET @centrosString_4 = ''
    SET @centrosString4_4 = ''
	SET @centrosString_5 = ''
    SET @centrosString5_5 = ''
	SET @centrosString_6 = ''
    SET @centrosString6_6 = ''
	SET @centrosString_7 = ''
    SET @centrosString7_7 = ''
	SET @centrosString_8 = ''
    SET @centrosString8_8 = ''
	SET @centrosString_9 = ''
    SET @centrosString9_9 = ''
	SET @centrosString_10 = ''
    SET @centrosString10_10 = ''
	SET @centrosString_11 = ''
    SET @centrosString11_11 = ''
	SET @centrosString_12 = ''
    SET @centrosString12_12 = ''
	SET @centrosString_13 = ''
    SET @centrosString13_13 = ''
	SET @centrosString_14 = ''
    SET @centrosString14_14 = ''
	SET @centrosString_15 = ''
    SET @centrosString15_15 = ''
	SET @centrosString_16 = ''
    SET @centrosString16_16 = ''
	SET @centrosString_17 = ''
    SET @centrosString17_17 = ''
	SET @centrosString_18 = ''
    SET @centrosString18_18 = ''
	SET @centrosString_19 = ''
    SET @centrosString19_19 = ''
	SET @centrosString_20 = ''
    SET @centrosString20_20 = ''

    
    DECLARE @tmpCent1 udtStringSize1024
    DECLARE @tmpCent2 udtStringSize1024
    DECLARE @primerCentro udtName
	
	SET @tmpCent1 = ''
	SET @tmpCent2 = ''

    INSERT  INTO dbo.tmp_centros_SABANA
            ( centro ,
              serial 
            )
            SELECT DISTINCT
                    ( centro ) ,
                    dense_rank() OVER ( PARTITION  BY 0 ORDER BY centro ) serial
            FROM    dbo.tmp_Detalle_SABANA
            WHERE NOT centro IS NULL AND tipo_conc<=3
            
	SET @primerCentro = (SELECT centro FROM dbo.tmp_centros_SABANA WHERE serial=1)   
	
	SET @totalRows = ISNULL(( SELECT    MAX(serial)
                              FROM      dbo.tmp_centros_SABANA
                            ), 0)

    --select * from dbo.tmp_centros_SABANA
	DECLARE @Marca int
	set @marca=1
	
	WHILE @counter <= @totalRows 
        BEGIN
			
			SET @tmpCent1 = ''
			SET @tmpCent2 = ''
			
			SET @tmpCent1 = ',isnull(['
                + ( SELECT  centro
                    FROM    dbo.tmp_centros_SABANA
                    WHERE   serial = @counter
                  ) + '],0) as ''' + ( SELECT  centro
                    FROM    dbo.tmp_centros_SABANA
                    WHERE   serial = @counter
                  ) +''''
			SET @tmpCent2 =	',['
                + ( SELECT  centro
                    FROM    dbo.tmp_centros_SABANA
                    WHERE   serial = @counter
                  ) + ']'
			
			if @marca = 1
			begin
				IF LEN(@centrosString) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 2
				end
			end
			else if  @Marca = 2
			begin
				IF LEN(@centrosString_2) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 3
				end
			end 
			else if  @Marca = 3
			begin
				IF LEN(@centrosString_3) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 4
				end
			end
			else if  @Marca = 4
			begin
				IF LEN(@centrosString_4) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 5
				end
			end
			else if  @Marca = 5
			begin
				IF LEN(@centrosString_5) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 6
				end
			end 
			else if  @Marca = 6
			begin
				IF LEN(@centrosString_6) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 7
				end
			end 
			else if  @Marca = 7
			begin
				IF LEN(@centrosString_7) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 8
				end
			end 
			else if  @Marca = 8
			begin
				IF LEN(@centrosString_8) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 9
				end
			end 
			else if  @Marca = 9
			begin
				IF LEN(@centrosString_9) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 10
				end
			end 
			else if  @Marca = 10
			begin
				IF LEN(@centrosString_10) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 11
				end
			end 
			else if  @Marca = 11
			begin
				IF LEN(@centrosString_11) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 12
				end
			end 
			else if  @Marca = 12
			begin
				IF LEN(@centrosString_12) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 13
				end
			end 
			else if  @Marca = 13
			begin
				IF LEN(@centrosString_13) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 14
				end
			end 
			else if  @Marca = 14
			begin
				IF LEN(@centrosString_14) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 15
				end
			end 
			else if  @Marca = 15
			begin
				IF LEN(@centrosString_15) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 16
				end
			end 
			else if  @Marca = 16
			begin
				IF LEN(@centrosString_16) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 17
				end
			end 
			else if  @Marca = 17
			begin
				IF LEN(@centrosString_17) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 18
				end
			end 
			else if  @Marca = 18
			begin
				IF LEN(@centrosString_18) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 19
				end
			end 
			else if  @Marca = 19
			begin
				IF LEN(@centrosString_19) + LEN(@tmpCent1) > 8000
				begin 
					set @marca = 20
				end
			end 
			if @marca = 1
			begin
				SET @centrosString = @centrosString + @tmpCent1
				SET @centrosString2 = @centrosString2 + @tmpCent2
			end
			if @marca = 2
			begin
				SET @centrosString_2 = @centrosString_2 + @tmpCent1
				SET @centrosString2_2 = @centrosString2_2 + @tmpCent2
			end
			if @marca = 3
			begin
				SET @centrosString_3 = @centrosString_3 + @tmpCent1
				SET @centrosString3_3 = @centrosString3_3 + @tmpCent2
			end
			if @marca = 4
			begin
				SET @centrosString_4 = @centrosString_4 + @tmpCent1
				SET @centrosString4_4 = @centrosString4_4 + @tmpCent2
			end
			if @marca = 5
			begin
				SET @centrosString_5 = @centrosString_5 + @tmpCent1
				SET @centrosString5_5 = @centrosString5_5 + @tmpCent2
			end
			if @marca = 6
			begin
				SET @centrosString_6 = @centrosString_6 + @tmpCent1
				SET @centrosString6_6 = @centrosString6_6 + @tmpCent2
			end
			if @marca = 7
			begin
				SET @centrosString_7 = @centrosString_7 + @tmpCent1
				SET @centrosString7_7 = @centrosString7_7 + @tmpCent2
			end
			if @marca = 8
			begin
				SET @centrosString_8 = @centrosString_8 + @tmpCent1
				SET @centrosString8_8 = @centrosString8_8 + @tmpCent2
			end
			if @marca = 9
			begin
				SET @centrosString_9 = @centrosString_9 + @tmpCent1
				SET @centrosString9_9 = @centrosString9_9 + @tmpCent2
			end
			if @marca = 10
			begin
				SET @centrosString_10 = @centrosString_10 + @tmpCent1
				SET @centrosString10_10 = @centrosString10_10 + @tmpCent2
			end
			if @marca = 11
			begin
				SET @centrosString_11 = @centrosString_11 + @tmpCent1
				SET @centrosString11_11 = @centrosString11_11 + @tmpCent2
			end
			if @marca = 12
			begin
				SET @centrosString_12 = @centrosString_12 + @tmpCent1
				SET @centrosString12_12 = @centrosString12_12 + @tmpCent2
			end
			if @marca = 13
			begin
				SET @centrosString_13 = @centrosString_13 + @tmpCent1
				SET @centrosString13_13 = @centrosString13_13 + @tmpCent2
			end
			if @marca = 14
			begin
				SET @centrosString_14 = @centrosString_14 + @tmpCent1
				SET @centrosString14_14 = @centrosString14_14 + @tmpCent2
			end
			if @marca = 15
			begin
				SET @centrosString_15 = @centrosString_15 + @tmpCent1
				SET @centrosString15_15 = @centrosString15_15 + @tmpCent2
			end
			if @marca = 16
			begin
				SET @centrosString_16 = @centrosString_16 + @tmpCent1
				SET @centrosString16_16 = @centrosString16_16 + @tmpCent2
			end
			if @marca = 17
			begin
				SET @centrosString_17 = @centrosString_17 + @tmpCent1
				SET @centrosString17_17 = @centrosString17_17 + @tmpCent2
			end
			if @marca = 18
			begin
				SET @centrosString_18 = @centrosString_18 + @tmpCent1
				SET @centrosString18_18 = @centrosString18_18 + @tmpCent2
			end
			if @marca = 19
			begin
				SET @centrosString_19 = @centrosString_19 + @tmpCent1
				SET @centrosString19_19 = @centrosString19_19 + @tmpCent2
			end
			if @marca = 20
			begin
				SET @centrosString_20 = @centrosString_20 + @tmpCent1
				SET @centrosString20_20 = @centrosString20_20 + @tmpCent2
			end
			
            SET @counter = @counter + 1 
        END
 
  --Inserta Segundo Detalle
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT k.num_conc AS ''Concepto'','
        + ' k.concepto AS ''Nombre del Concepto'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + '''' + @primerCentro + ''','
        + 'case when k.tipo_conc = 1 then 5 when k.tipo_conc = 2 then 7 when k.tipo_conc = 3 then 9 end  as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc <= 3 and (k.num_conc> 0 and k.num_conc<999999)'
		+ ' GROUP BY k.tipo_conc,k.num_conc,k.concepto)'
		
        
        

    IF @debug = 0 
        BEGIN

            EXEC (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
	Print '7'
	--Inserta Totales Percepciones Segundo Detalle
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT null AS ''Concepto'','
        + ' ''TOTAL PERCEPCIONES'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + '''' + @primerCentro + ''','
        + '6  as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 1 and (k.num_conc> 0 and k.num_conc<999999)'
		+ ' GROUP BY k.tipo_conc)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''PERCEPCIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '5 as tipo_conc) '

    IF @debug = 0 
        BEGIN

            exec (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
Print '8'
	--Inserta Totales DEDUCCIONES Segundo Detalle
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT null AS ''Concepto'','
        + ' ''TOTAL DEDUCCIONES'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + '''' + @primerCentro + ''','
        + '8 as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 2 and (k.num_conc> 0 and k.num_conc<999999)'
		+ ' GROUP BY k.tipo_conc)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''DEDUCCIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '7 as tipo_conc) '
    IF @debug = 0 
        BEGIN

            exec (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
	Print '9'
        --Inserta Totales PROVISIONES Segundo Detalle
    
    SET @selectClause = 'INSERT INTO dbo.tmp_Detalle_SABANA ( num_conc, concepto, importe, centro , tipo_conc ) '
        + '(SELECT null AS ''Concepto'','
        + ' ''TOTAL PROVISIONES'','
        + 'SUM(K.IMPORTE) AS ''Importe'','
        + '''' + @primerCentro + ''','
        + '10 as tipo_conc '
		+ 'FROM dbo.tmp_Detalle_SABANA AS k '
		+ 'WHERE K.tipo_conc = 3 and (k.num_conc> 0 and k.num_conc<999999)'
		+ ' GROUP BY k.tipo_conc)'
		+ ' UNION '
		+ '(SELECT 0 AS ''Concepto'','
        + ' ''PROVISIONES'' AS ''Nombre del Concepto'','
        + 'NULL AS ''Importe'','
        + 'NULL AS ''Departamento'','
        + '9 as tipo_conc) '

    IF @debug = 0 
        BEGIN

            exec (@selectClause )
        END 
    ELSE 
        BEGIN
	
            PRINT ( @selectClause )
        END
 Print '10'
    SET @centrosString = SUBSTRING(@centrosString, 2, LEN(@centrosString))
    SET @centrosString2 = SUBSTRING(@centrosString2, 2, LEN(@centrosString2))
   

    DECLARE @fromClausePivot udtStringSize4096
    DECLARE @selectClausePivot udtStringSize4096
    DECLARE @whereClausePivot udtStringSize4096
    DECLARE @orderByClausePivot udtStringSize4096

    SET @selectClausePivot = ' SELECT  num_conc as Clave, concepto as Concepto, '
    SET @fromClausePivot = 'FROM    ( SELECT    num_conc, concepto, importe, centro, tipo_conc '
        + 'FROM dbo.tmp_Detalle_SABANA '
        + ') AS deducciones PIVOT( SUM(importe )FOR centro IN ('
						
    SET @orderByClausePivot = ' ) ) AS PivotTable ' + ' ORDER BY tipo_conc,num_conc '
	
	
    IF @debug = 0
        BEGIN

            exec(@selectClausePivot + @centrosString + @centrosString_2 + @centrosString_3 + @centrosString_4 + @centrosString_5 + @centrosString_6 + @centrosString_7 + @centrosString_8 + @centrosString_9 + @centrosString_10 + @centrosString_11 + @centrosString_12 + @centrosString_13 + @centrosString_14 + @centrosString_15 + @centrosString_16 + @centrosString_17 + @centrosString_18 + @centrosString_19 + @centrosString_20 +
            @fromClausePivot + @centrosString2 + @centrosString2_2 + @centrosString3_3 + @centrosString4_4 + @centrosString5_5 + @centrosString6_6 + @centrosString7_7 + @centrosString8_8 + @centrosString9_9 + @centrosString10_10 + @centrosString11_11 + @centrosString12_12 + @centrosString13_13 + @centrosString14_14 + @centrosString15_15 + @centrosString16_16 + @centrosString17_17 + @centrosString18_18 + @centrosString19_19 + @centrosString20_20 +
            @orderByClausePivot)
        END 
    ELSE 
        BEGIN
	        select  @selectClausePivot , @centrosString , @centrosString_2 , @centrosString_3 , @centrosString_4 , @centrosString_5 , @centrosString_6 , @centrosString_7 , @centrosString_8 , @centrosString_9 , @centrosString_10 , @centrosString_11 , @centrosString_12 , @centrosString_13 , @centrosString_14 , @centrosString_15 , @centrosString_16 , @centrosString_17 , @centrosString_18 , @centrosString_19 , @centrosString_20 ,
            @fromClausePivot , @centrosString2 , @centrosString2_2 , @centrosString3_3 , @centrosString4_4 , @centrosString5_5 , @centrosString6_6 , @centrosString7_7 , @centrosString8_8 , @centrosString9_9 , @centrosString10_10 , @centrosString11_11 , @centrosString12_12 , @centrosString13_13 , @centrosString14_14 , @centrosString15_15 , @centrosString16_16 , @centrosString17_17 , @centrosString18_18 , @centrosString19_19 , @centrosString20_20 ,
            @orderByClausePivot
        END 
Print '11'		

    IF OBJECT_ID('dbo.tmp_KADetalle') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_KADetalle
        END
	IF OBJECT_ID('dbo.tmp_Detalle_SABANA') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_Detalle_SABANA
        END
    IF OBJECT_ID('dbo.tmp_centros_SABANA') IS NOT NULL 
        BEGIN
            DROP TABLE dbo.tmp_centros_SABANA
        END


GO


 IF NOT EXISTS ( SELECT *
                 FROM   dbo.sysobjects
                 WHERE  id = OBJECT_ID(N'[dbo].[PortalPatron_Multiple]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    CREATE TABLE [dbo].[PortalPatron_Multiple]
        (
          [llave] [BigInt] NOT NULL ,
          [nombre_empresa] [Varchar](70) NULL ,
          [rfc_empresa] [Varchar](15) NULL ,
          [reg_patronal] [Varchar](15) NULL ,
          CONSTRAINT [PK_PortalPatron_Multiple] PRIMARY KEY CLUSTERED
            ( [llave] ASC )
        )
    ON  [PRIMARY]

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronEncabezados')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronEncabezados
GO


CREATE PROCEDURE dbo.Obten_PortalPatronEncabezados
    (
      @encabezado udtLong ,
      @llave udtLong 
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @totalEmpresas udtLong
    
    SET @totalEmpresas = ISNULL(( SELECT DISTINCT
                                            ( COUNT(empresa) )
                                  FROM      dbo.tmpAccesoPortalPatron
                                  WHERE     llave = @llave
                                ), 0)
    
    IF @totalEmpresas = 1 
        BEGIN
            SELECT  a.nombre_empresa ,
                    a.registro_patronal ,
                    a.rfc_empresa
            FROM    dbo.empresas AS a
                    INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa
            WHERE   b.llave = @encabezado
        END
    ELSE 
        BEGIN
			
            IF EXISTS ( SELECT  nombre_empresa ,
                                reg_patronal ,
                                rfc_empresa
                        FROM    dbo.PortalPatron_Multiple
                        WHERE   llave = @encabezado ) 
                BEGIN
                    SELECT  nombre_empresa ,
                            reg_patronal ,
                            rfc_empresa
                    FROM    dbo.PortalPatron_Multiple
                    WHERE   llave = @encabezado
                END
            ELSE 
                BEGIN
                    SELECT  'MULTIPLE' AS nombre_empresa ,
                            'MULTIPLE' AS reg_patronal ,
                            'MULTIPLE' AS rfc_empresa
                END
        END
	
    
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Guarda_PortalPatronEncabezados')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Guarda_PortalPatronEncabezados
GO


CREATE PROCEDURE dbo.Guarda_PortalPatronEncabezados
    (
      @llave udtLong ,
      @nombre udtStringSize128 ,
      @rfc udtStringSize128 ,
      @regPat udtStringSize128
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    IF NOT EXISTS ( SELECT  nombre_empresa ,
                        reg_patronal ,
                        rfc_empresa
                FROM    dbo.PortalPatron_Multiple
                WHERE   llave = @llave ) 
        BEGIN
            INSERT  INTO dbo.PortalPatron_Multiple
                    ( llave ,
                      nombre_empresa ,
                      rfc_empresa ,
                      reg_patronal
                    )
            VALUES  ( @llave , -- llave - bigint
                      @nombre , -- nombre_empresa - varchar(70)
                      @rfc , -- rfc_empresa - varchar(15)
                      @regPat  -- reg_patronal - varchar(15)
                    )
        END
    ELSE 
        BEGIN
            UPDATE  dbo.PortalPatron_Multiple
            SET     nombre_empresa = @nombre ,
                    rfc_empresa = @rfc ,
                    reg_patronal = @regPat
            WHERE   llave = @llave
        END
	
    
GO

IF OBJECT_ID('dbo.tmp_15x11_TotalesFilas') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_TotalesFilas
    END
                
IF OBJECT_ID('dbo.tmp_15x11_Conceptos') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_Conceptos
    END
IF OBJECT_ID('dbo.tmp_15x11_Empresas') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_Empresas
    END

GO


/**************************************************************************************************
 * Name          : PortalPatronObtenNomina15x11
 * Project       : APSISISTEMAS
 * Description   : ObtenTotalesPeriodoPorColumnas
 * Table name    : 
 * Copyright     : APSI SA, de CV 2010 - 2015. All rights reserved
 * Company       : APSI SA, de CV
 * Author        : adan.sanchez@apsi.com.mx
 * Creation date : viernes, 28 de enero de 2013
 **************************************************************************************************/

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.PortalPatronObtenNomina15x11')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.PortalPatronObtenNomina15x11
GO


CREATE PROCEDURE dbo.PortalPatronObtenNomina15x11(
    @payrollType udtInteger ,
    @periodId udtInteger ,
    @periodId2 udtInteger ,
    @yearId udtInteger,
    @typeReport udtName,
    @nominas udtStringSize1024,
    @mes udtName,
	@nominaActiva int=0,
    @keyId udtLong)
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @recordId AS udtId
    
    DECLARE @conceptoMeter udtInteger
    DECLARE @headerStirng udtStringSize2048
    DECLARE @conceptStirng udtStringSize2048
    DECLARE @sqlStirng udtStringSize8000
    DECLARE @sqlStirng2 udtStringSize8000
    DECLARE @selectClause udtStringSize4096
    DECLARE @fromClause udtStringSize4096
    DECLARE @whereClause udtStringSize2048
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @groupByClause AS udtStringSize4096
    DECLARE @orderByClause AS udtStringSize4096
    
    SET @whereClauseUsed = 0
    SET @selectClause = ''
    SET @fromClause = ''
    SET @whereClause = ''
    SET @headerStirng = ''
    SET @conceptStirng = ''
    SET @sqlStirng = ''
    SET @conceptoMeter = @periodId 
    SET @groupByClause = ''
    SET @orderByClause = ''
    DECLARE @maxMeter BIGINT
    DECLARE @minMeter BIGINT
    DECLARE @conceptosString udtStringSize8000
    
    
    IF OBJECT_ID('dbo.tmp_15x11_Empresas') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_Empresas
    END
	CREATE TABLE dbo.tmp_15x11_Empresas(empresa INT,nombre_empresa VARCHAR(250))
    
    INSERT INTO tmp_15x11_Empresas
        ( empresa, nombre_empresa )
	SELECT a.empresa,a.nombre_empresa
	FROM dbo.empresas AS a 
	INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa
	WHERE b.llave = @keyId

    DECLARE @conceptos AS TABLE
        (
          num_conc udtInteger ,
          concepto udtName, 
          serial udtLong
        )
        
    IF OBJECT_ID('dbo.tmp_15x11_Conceptos') IS NOT NULL 
                BEGIN
                    DROP TABLE dbo.tmp_15x11_Conceptos
                END
	CREATE TABLE dbo.tmp_15x11_Conceptos(num_conc udtInteger,concepto udtName, grupo udtName,tipoConcepto udtInteger)
	
	
	
	IF OBJECT_ID('dbo.tmp_15x11_TotalesFilas') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_TotalesFilas
    END
	CREATE TABLE dbo.tmp_15x11_TotalesFilas
	(
		grupo udtName NOT  NULL,
		nombreGrupo udtStringSize128 NOT  NULL,
		empresa BIGINT NOT NULL,
		codigo BIGINT NOT  NULL,
		num_conc udtInteger NOT NULL,
		concepto udtName NULL,
		importe NUMERIC(12,2) NULL,
		centro udtName NULL,
		ocupacion udtInteger NULL,
		clase udtName NULL,
		horario udtInteger NULL,
		dias udtNumeric10_2 NULL,
		faltas udtNumeric10_2 NULL,
		inc udtNumeric10_2 NULL,
		DsPrimVac udtNumeric10_2 NULL,
		LabDsDesc udtNumeric10_2 NULL,
		TpoExtDob udtNumeric10_2 NULL,
		TpoExtTri udtNumeric10_2 NULL,
		supervisor udtInteger NULL,
		mes VARCHAR(6) NULL ,
		periodo udtInteger NULL,
		Tipo int NULL
	)

	--Tabla para poder sumar el periodo activo
	Declare @tmp_15x11_TotalesFilas as table
	(
		grupo udtName NOT  NULL,
		nombreGrupo udtStringSize128 NOT  NULL,
		empresa BIGINT NOT NULL,
		codigo BIGINT NOT  NULL,
		num_conc udtInteger NOT NULL,
		concepto udtName NULL,
		importe NUMERIC(12,2) NULL,
		centro udtName NULL,
		ocupacion udtInteger NULL,
		clase udtName NULL,
		horario udtInteger NULL,
		dias udtNumeric10_2 NULL,
		faltas udtNumeric10_2 NULL,
		inc udtNumeric10_2 NULL,
		diasvac udtNumeric10_2 NULL,
		LabsDesc udtNumeric10_2 NULL,
		dobles udtNumeric10_2 NULL,
		triples udtNumeric10_2 NULL,
		supervisor udtInteger NULL,
		mes VARCHAR(6) NULL ,
		periodo udtInteger NULL,
		Tipo int NULL,
		nomina varchar(10)
	)
	
	--Establecer periodos validos si @nominaActiva=2 los periodos se igualan a cero, solo se toma en cuenta la nomina activa
	if @nominaActiva=2
	begin
		set @periodId=0
		set @periodId2=0
	end
	else begin
		set @periodId2 = case when @periodId2<@periodId then @periodId else @periodId2 end
		set @periodId=case when @periodId<=0 then 1 else @periodId end 
		set @periodId2=case when @periodId2<=0 then 99 else @periodId2 end
	end 
	
	--select @periodId asperiodId,@periodId2 as periodId2, @payrollType as payrollType, @yearId as yearId,@mes as mes,@nominas as nominas, @nominaActiva as nominaActiva

     
     IF OBJECT_ID('dbo.tmp_15x11_TotalesDiasHoras') IS NOT NULL 
    BEGIN
        DROP TABLE dbo.tmp_15x11_TotalesDiasHoras
    END
	CREATE TABLE dbo.tmp_15x11_TotalesDiasHoras
	(
		grupo udtName NOT  NULL,
		nombreGrupo udtStringSize128 NOT  NULL,
		empresa BIGINT NOT NULL,
		codigo BIGINT NOT  NULL,
		centro udtName NULL,
		ocupacion udtInteger NULL,
		clase udtName NULL,
		horario udtInteger NULL,
		supervisor udtInteger NULL,
		dias udtNumeric10_2 NULL,
		faltas udtNumeric10_2 NULL,
		inc udtNumeric10_2 NULL,
		DsPrimVac udtNumeric10_2 NULL,
		LabDsDesc udtNumeric10_2 NULL,
		TpoExtDob udtNumeric10_2 NULL,
		TpoExtTri udtNumeric10_2 NULL,
		mes VARCHAR(6) NULL ,
		periodo udtInteger NULL		
	)       
			DECLARE @tableString udtStringSize8000
			
			SET @tableString = ' '


			
			
				insert into @tmp_15x11_TotalesFilas
				SELECT  CASE	WHEN @typeReport = 'E' THEN REPLICATE('9',15-LEN(LTRIM(RTRIM(STR(k.empresa)))))  + LTRIM(RTRIM(STR(k.empresa))) 
								WHEN @typeReport = 'C' THEN REPLICATE('9',20-LEN(LTRIM(RTRIM(ISNULL(n.centro,l.centro)))))  + LTRIM(RTRIM(ISNULL(n.centro,l.centro)))
								WHEN @typeReport = 'P' THEN REPLICATE('0',15-LEN(LTRIM(RTRIM(STR(k.periodo)))))  + LTRIM(RTRIM(STR(k.periodo)))
						END as grupo ,
						CASE	WHEN @typeReport = 'E' THEN em.nombre_empresa
								WHEN @typeReport = 'C' THEN ltrim(rtrim(cen.centro)) + ' ' + cen.nomdepto
								WHEN @typeReport = 'P' THEN 'PERIODO: '  + LTRIM(RTRIM(STR(k.periodo)))
						END as nombreGrupo ,
						k.empresa,
						k.codigo, 
						k.num_conc,
						k.concepto,
						k.importe,
						ISNULL(n.centro,l.centro) as centro,
						ISNULL(n.ocupacion,l.ocupacion) as ocupacion,
						l.clase as Clase,
						ISNULL(n.horario,l.horario) as horario,
						case when k.num_conc in(1,2,3,4,5,6,7,30) then k.dias else 0 end as diastr_nom,
						isnull(case when k.num_conc = 108 then k.dias else 0 end,0) faltas,
						isnull(case when k.num_conc in(109,110,111) then k.dias else 0 end,0) inc,
						case when k.num_conc=17 then k.dias else 0 end as diasvac,
						case when k.num_conc=10 then k.horas else 0 end as labsdesc,
						case when k.num_conc=12 or k.num_conc=11 then k.horas else 0 end as dobles,
						case when k.num_conc=13 then k.horas else 0 end as triples,
						ISNULL(n.supervisor,l.supervisor) as supervisor, 
						CASE WHEN @typeReport = 'P' THEN k.Mes ELSE '' END AS Mes,
						CASE WHEN @typeReport = 'P' THEN k.periodo ELSE 0 END AS Periodo,
						CASE	WHEN (( k.num_conc >= 1 AND K.num_conc <= 99) OR ( K.num_conc >= 501 AND k.num_conc <= 599) OR ( k.num_conc >= 1101 AND k.num_conc <= 1199)) THEN 1 
								WHEN (( k.num_conc >= 101 AND K.num_conc <= 199) OR ( K.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1999)) THEN 2 
								WHEN (k.num_conc >= 201 AND K.num_conc <= 299)  THEN 3 
						END as Tipo ,
						k.nomina
				FROM      dbo.kardex_anual AS k 
				LEFT JOIN dbo.nomina1_anual as n on n.empresa=k.empresa and n.codigo=k.codigo and n.nomina='ORD' and n.periodo=k.periodo and n.ayo_operacion=k.ayo_operacion and n.tiponom=k.tiponom 
				INNER JOIN dbo.llaves as l on k.empresa=l.empresa and k.codigo=l.codigo 
				INNER JOIN dbo.tmp_15x11_Empresas as em on em.empresa=k.empresa 
				INNER JOIN dbo.centros as cen on k.empresa=cen.empresa and cen.centro=ISNULL(n.centro, l.centro)
				where	(k.periodo between @periodId and @periodId2)
						and case when @payrollType<=0 then 0 else k.tiponom end=case when @payrollType<=0 then 0 else @payrollType end
						and case when @yearId <=0 then 0 else k.ayo_operacion end =case when @yearId <=0 then 0 else @yearId end
						and case when len(@mes)>0 then k.mes else '' end=case when len(@mes)>0 then @mes else '' end
						and k.nomina in(
										case when CHARINDEX('ORD',@nominas)>0 then 'ORD' else '' end,
										case when CHARINDEX('FIN',@nominas)>0 then 'FIN' else '' end,
										case when CHARINDEX('VAC',@nominas)>0 then 'VAC' else '' end,
										case when CHARINDEX('VAL',@nominas)>0 then 'VAL' else '' end,
										case when CHARINDEX('PTU',@nominas)>0 then 'PTU' else '' end,
										case when CHARINDEX('AGI',@nominas)>0 then 'AGI' else '' end,
										case when CHARINDEX('OTR',@nominas)>0 then 'OTR' else '' end
										)
						--and k.codigo=105
				
				insert into @tmp_15x11_TotalesFilas
				SELECT  CASE	WHEN @typeReport = 'E' THEN REPLICATE('9',15-LEN(LTRIM(RTRIM(STR(k.empresa)))))  + LTRIM(RTRIM(STR(k.empresa))) 
								WHEN @typeReport = 'C' THEN REPLICATE('9',20-LEN(LTRIM(RTRIM(l.centro))))  + LTRIM(RTRIM(l.centro))
								WHEN @typeReport = 'P' THEN REPLICATE('0',15-LEN(LTRIM(RTRIM(STR(p.periodo)))))  + LTRIM(RTRIM(STR(p.periodo)))
						END as grupo ,
						CASE	WHEN @typeReport = 'E' THEN em.nombre_empresa
								WHEN @typeReport = 'C' THEN ltrim(rtrim(cen.centro)) + ' ' + cen.nomdepto
								WHEN @typeReport = 'P' THEN 'PERIODO: '  + LTRIM(RTRIM(STR(p.periodo)))
						END as nombreGrupo ,
						k.empresa,
						k.codigo, 
						k.num_conc,
						k.concepto,
						k.importe,
						l.centro as centro,
						l.ocupacion as ocupacion,
						l.clase as Clase,
						l.horario as horario,
						case when k.num_conc in(1,2,3,4,5,6) then k.dias else 0 end as diastr_nom,
						isnull(case when k.num_conc = 108 then k.dias else 0 end,0) faltas,
						isnull(case when k.num_conc in(109,110,111) then k.dias else 0 end,0) inc,
						case when k.num_conc=17 then k.dias else 0 end as diasvac,
						case when k.num_conc=10 then k.horas else 0 end as labsdesc,
						case when k.num_conc=12 or k.num_conc=11 then k.horas else 0 end as dobles,
						case when k.num_conc=13 then k.horas else 0 end as triples,
						l.supervisor as supervisor, 
						CASE WHEN @typeReport = 'P' THEN	case	when month(p.pago)=1 then 'ENE' 
																	when month(p.pago)=2 then 'FEB' 
																	when month(p.pago)=3 then 'MAR' 
																	when month(p.pago)=4 then 'ABR' 
																	when month(p.pago)=5 then 'MAY' 
																	when month(p.pago)=6 then 'JUN' 
																	when month(p.pago)=7 then 'JUL' 
																	when month(p.pago)=8 then 'AGO' 
																	when month(p.pago)=9 then 'SEP' 
																	when month(p.pago)=10 then 'OCT' 
																	when month(p.pago)=11 then 'NOV' 
																	when month(p.pago)=12 then 'DIC' 
															end + substring(convert(varchar,p.ayo_operacion),3,2) 
						ELSE '' END AS Mes,
						CASE WHEN @typeReport = 'P' THEN p.periodo ELSE 0 END AS Periodo,
						CASE	WHEN (( k.num_conc >= 1 AND K.num_conc <= 99) OR ( K.num_conc >= 501 AND k.num_conc <= 599) OR ( k.num_conc >= 1101 AND k.num_conc <= 1199)) THEN 1 
								WHEN (( k.num_conc >= 101 AND K.num_conc <= 199) OR ( K.num_conc >= 601 AND k.num_conc <= 699) OR ( k.num_conc >= 1001 AND k.num_conc <= 1999)) THEN 2 
								WHEN (k.num_conc >= 201 AND K.num_conc <= 299)  THEN 3 
						END as Tipo ,
						k.nomina
				FROM      dbo.kardex AS k 
				INNER JOIN dbo.llaves as l on k.empresa=l.empresa and k.codigo=l.codigo 
				inner join dbo.periodos as p on p.empresa=l.empresa and p.tiponom=l.tiponom and p.estatus='A'
				INNER JOIN dbo.tmp_15x11_Empresas as em on em.empresa=k.empresa 
				INNER JOIN dbo.centros as cen on k.empresa=cen.empresa and cen.centro=l.centro
				where	case when @payrollType<=0 then 0 else l.tiponom end=case when @payrollType<=0 then 0 else @payrollType  end
						and case when @nominaActiva>=2 then 1 else 0 end=1
						and k.nomina in('SEM','DEC','CAT','QNA','MES','ESP',
										case when CHARINDEX('FIN',@nominas)>0 then 'FIN' else '' end,
										case when CHARINDEX('VAC',@nominas)>0 then 'VAC' else '' end,
										case when CHARINDEX('VAL',@nominas)>0 then 'VAL' else '' end,
										case when CHARINDEX('PTU',@nominas)>0 then 'PTU' else '' end,
										case when CHARINDEX('AGI',@nominas)>0 then 'AGI' else '' end,
										case when CHARINDEX('OTR',@nominas)>0 then 'OTR' else '' end
										)
						--and k.codigo=105
				
			INSERT INTO dbo.tmp_15x11_TotalesFilas
			select	a.Grupo,a.nombreGrupo,a.empresa,a.codigo,a.num_conc,max(concepto) as Concepto,sum(importe) as importe,
					max(b.centro) as centro,max(b.ocupacion) as ocupacion,max(b.clase) as clase,max(b.horario) as horario,
					sum(dias) as dias,sum(faltas) as faltas, sum(inc) as inc,sum(diasvac) as diasvax,
					sum(labsdesc) as labdesc,sum(dobles) as dobles,sum(triples) as triples,max(b.supervisor) as supervisor,
					mes,case when @typeReport = 'P' then periodo else 0 end as periodo,
					Tipo
			from @tmp_15x11_TotalesFilas as a
			inner join(	select	a.Grupo,a.nombreGrupo,a.empresa,a.codigo,
								max(a.centro) as centro,max(a.ocupacion) as ocupacion,max(a.clase) as clase,max(a.horario) as horario,
								max(a.supervisor) as supervisor
						from @tmp_15x11_TotalesFilas as a
						Group by a.Grupo,a.nombreGrupo,a.empresa,a.codigo) as b on b.Grupo=a.Grupo and b.nombreGrupo=a.nombreGrupo and b.empresa=a.empresa and b.codigo=a.codigo
			Group by a.Grupo,a.nombreGrupo,a.empresa,a.codigo,a.num_conc,a.mes,a.tipo,a.periodo

			--select * from @tmp_15x11_TotalesFilas

			--EXEC(@selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause )

			--select * from tmp_15x11_TotalesFilas where codigo=105

			--Totales Dias Horas
			INSERT INTO dbo.tmp_15x11_TotalesDiasHoras(Grupo,nombreGrupo,
					empresa,
					codigo,
					centro,
					ocupacion,
					clase,
					horario,
					supervisor,
					mes,
					periodo,
					dias,
					faltas,
					inc,
					DsPrimVac,
					LabDsDesc,
					TpoExtDob,
					TpoExtTri)
			SELECT	Grupo,nombreGrupo,
					empresa,
					codigo,
					centro,
					ocupacion,
					clase,
					horario,
					supervisor,
					mes,
					periodo,
					SUM(dias),
					SUM(faltas),
					SUM(inc),
					SUM(DsPrimVac),
					SUM(LabDsDesc),
					SUM(TpoExtDob),
					SUM(TpoExtTri)
			FROM dbo.tmp_15x11_TotalesFilas
			GROUP BY grupo,
					nombreGrupo,
					empresa,
					codigo,
					centro,
					ocupacion,
					clase,
					horario,
					supervisor,
					mes,
					periodo	
		

	
	SET @conceptosString = ' '
    
    SET @conceptosString = 'SELECT  k.num_conc ,MAX(concepto) as concepto,' + '''' + @typeReport + ''',k.tipo'
        + ' FROM    dbo.tmp_15x11_TotalesFilas as k ' 
        + ' GROUP BY tipo,num_conc '
        + ' ORDER BY tipo,num_conc'

    INSERT  INTO dbo.tmp_15x11_Conceptos
            ( num_conc ,
				 concepto,
              grupo,
              tipoConcepto 
            )
            EXEC ( @conceptosString)
    
    INSERT  INTO dbo.tmp_15x11_Conceptos
            ( num_conc ,
              concepto,
              grupo ,
              tipoConcepto
            )VALUES(1999,'PERCEPCIONES',@typeReport,1)
    INSERT  INTO dbo.tmp_15x11_Conceptos
            ( num_conc ,
              concepto,
              grupo ,
              tipoConcepto
            ) VALUES(2999,'DEDUCCIONES',@typeReport,2)
	INSERT  INTO dbo.tmp_15x11_Conceptos
            ( num_conc ,
              concepto,
              grupo ,
              tipoConcepto
            )VALUES(3999,'NETO',@typeReport,2)
	INSERT  INTO dbo.tmp_15x11_Conceptos
            ( num_conc ,
			  concepto,
              grupo ,
              tipoConcepto
            )VALUES(4999,'PROVISIONES',@typeReport,3)

    --SELECT * FROM dbo.tmp_15x11_Conceptos
    
    SET @conceptosString = ' '
    
    SET @conceptosString = 'SELECT  k.num_conc,cast(MAX(k.concepto) as varchar(25)) as concepto,'
        + 'dense_rank() OVER ( PARTITION  BY k.grupo ORDER BY k.tipoConcepto,k.num_conc ) AS serial '
        + ' FROM    dbo.tmp_15x11_Conceptos as k ' 
        + ' GROUP BY k.tipoConcepto,k.grupo,k.num_conc'
        + ' ORDER BY k.tipoConcepto,k.grupo,k.num_conc '
	
	PRINT 'CONCEPTOS'
	
    INSERT  INTO @conceptos
            ( num_conc ,
              concepto,
              serial 
            )
            EXEC ( @conceptosString
                )
   
	SELECT  @minMeter = MIN(serial) ,
            @maxMeter = MAX(serial)
    FROM    @conceptos
	
    DECLARE @serialMeter BIGINT
    DECLARE @headerTypesStrind udtStringSize8000
    DECLARE @headerPivotStrind udtStringSize8000
    DECLARE @stringConceptos udtStringSize1024
    DECLARE @stringConceptos2 udtStringSize1024
    
    SET @serialMeter = @minMeter
    SET @headerTypesStrind = ''
    SET @headerPivotStrind = ''
    SET @stringConceptos = ''
    SET @stringConceptos2 = ''
    
    
    SET @serialMeter = @minMeter
    WHILE @serialMeter <= @maxMeter 
        BEGIN
			SET @stringConceptos = ''
			SET @stringConceptos2 = ''
			
			--Conceptos
			SET @stringConceptos = ( SELECT  '[' + RTRIM(LTRIM(STR(num_conc)))
                                            + '],'
                                    FROM    @conceptos
                                    WHERE   serial = @serialMeter
                                  )
            
            --encabezados
            SET @stringConceptos2 = ( SELECT  'isnull([' + RTRIM(LTRIM(STR(num_conc)))
                                            + '],0) as ''' + RTRIM(LTRIM(STR(num_conc)))
                                            + ' ' + RTRIM(LTRIM(concepto)) + ' '' ,'
                                    FROM    @conceptos
                                    WHERE   serial = @serialMeter
                                  )
            
            SET @headerTypesStrind = @headerTypesStrind + @stringConceptos  
            SET @headerPivotStrind = @headerPivotStrind + @stringConceptos2 
              
            SET @serialMeter = @serialMeter + 1
        END
    

    SET @headerTypesStrind = SUBSTRING(@headerTypesStrind, 1,(LEN(@headerTypesStrind) - 1))
    SET @headerPivotStrind = SUBSTRING(@headerPivotStrind, 1,(LEN(@headerPivotStrind) - 1))
       
    
    PRINT 'MET'
    		
			--Detalle DiasVac,Tpo Ext
			
			--UPDATE a SET dias = ISNULL(b.dias,a.dias)
			--FROM dbo.tmp_15x11_TotalesFilas  AS a
			--LEFT JOIN dbo.tmp_15x11_TotalesFilas  AS b ON a.grupo=b.grupo AND a.codigo=b.codigo AND b.num_conc<=6
			
			--UPDATE a SET DsPrimVac = b.DsPrimVac
			--FROM dbo.tmp_15x11_TotalesFilas  AS a
			--INNER JOIN dbo.tmp_15x11_TotalesFilas  AS b ON a.grupo=b.grupo AND a.codigo=b.codigo AND b.DsPrimVac>0
			
			--UPDATE a SET LabDsDesc = (select SUM(b.LabDsDesc) FROM dbo.tmp_15x11_TotalesFilas  AS b WHERE a.grupo=b.grupo AND a.codigo=b.codigo AND b.LabDsDesc>0)
			--FROM dbo.tmp_15x11_TotalesFilas  AS a
			
			--UPDATE a SET TpoExtDob = (select SUM(b.TpoExtDob) FROM dbo.tmp_15x11_TotalesFilas  AS b WHERE a.grupo=b.grupo AND a.codigo=b.codigo AND b.TpoExtDob>0)
			--FROM dbo.tmp_15x11_TotalesFilas  AS a
			
			--UPDATE a SET TpoExtTri = (select SUM(b.TpoExtTri) FROM dbo.tmp_15x11_TotalesFilas  AS b WHERE a.grupo=b.grupo AND a.codigo=b.codigo AND b.TpoExtTri>0)
			--FROM dbo.tmp_15x11_TotalesFilas  AS a
			
			
			--SELECT * FROM dbo.tmp_15x11_TotalesFilas  WHERE codigo=1012
			--Inserta totales por empleado(percepciones)
			SET @tableString = ' '
			
			SET @tableString = 'SELECT   n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ '1999 as num_conc,'
								+ ' '' '' as concepto,'
								+ 'SUM(n.importe)as importe,'
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor, '
								+ 'n.mes,'
								+ 'n.periodo,'
								+ ' 1 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								+ ' WHERE tipo=1 '
								+ ' GROUP BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo '
																
			INSERT INTO dbo.tmp_15x11_TotalesFilas--(grupo,nombreGrupo,codigo,num_conc,concepto,importe,centro,ocupacion,clase,horario)
			EXEC(@tableString)
			
			PRINT 'Percepciones'
			
			--Inserta totales por empleado(deducciones)
			SET @tableString = ' '
			
			SET @tableString = 'SELECT   n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ '2999 as num_conc,'
								+ ' '' '' as concepto,'
								+ 'SUM(n.importe)as importe,'
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo,'
								+ ' 2 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								+ ' WHERE tipo=2 '
								+ ' GROUP BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo '
								
			INSERT INTO dbo.tmp_15x11_TotalesFilas--(grupo,nombreGrupo,codigo,num_conc,concepto,importe,centro,ocupacion,clase,horario)
			EXEC(@tableString)
			
			--EXEC(@tableString)
			
			PRINT 'Deducciones'
			
			--Inserta totales por empleado(provisiones)
			SET @tableString = ' '
			
			SET @tableString = 'SELECT   n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ '4999 as num_conc,'
								+ ' '' '' as concepto,'
								+ 'SUM(n.importe)as importe,'
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo,'
								+ ' 3 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								+ ' WHERE tipo=3 '
								+ ' GROUP BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo '
								
			INSERT INTO dbo.tmp_15x11_TotalesFilas--(grupo,nombreGrupo,codigo,num_conc,concepto,importe,centro,ocupacion,clase,horario)
			EXEC(@tableString)
			
			PRINT 'Provisiones'
			
			--Inserta totales por empleado(neto)
			SET @tableString = ' '
			
			SET @tableString = 'SELECT   n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ '3999 as num_conc,'
								+ ' '' '' as concepto,'
								+' sum(case when n.num_conc = 1999 then isnull(n.importe,0) else 0 end) - sum(case when n.num_conc = 2999 then isnull(n.importe,0) else 0 end) as importe,'
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo,'
								+ ' 4 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								+ '	WHERE     n.num_conc in(1999,2999) '
								+ ' GROUP BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ 'n.empresa,' 
								+ 'n.codigo,' 
								+ 'n.centro,'
								+ 'n.ocupacion,'
								+ 'n.clase,'
								+ 'n.horario,'
								+ 'n.dias,'
								+ 'n.faltas,'
								+ 'n.inc,'
								+ 'n.DsPrimVac,'
								+ 'n.LabDsDesc,'
								+ 'n.TpoExtDob,'
								+ 'n.TpoExtTri,'
								+ 'n.supervisor,'
								+ 'n.mes,'
								+ 'n.periodo '

								
			INSERT INTO dbo.tmp_15x11_TotalesFilas--(grupo,nombreGrupo,codigo,num_conc,concepto,importe,centro,ocupacion,clase,horario)
			EXEC(@tableString)
			
			PRINT 'Por empleado'
			
			--Inserta totales por grupo
			
			SET @tableString = ' '
			
			SET @tableString = 'SELECT   n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ ' 0,'
								+ '999999999,' 
								+ 'n.num_conc,'
								+ ' '' '' as concepto,'
								+ 'SUM(n.importe) as importe,'
								+ + '''Emps. '' + rtrim(ltrim(str((select count(DISTINCT(a.codigo)) from dbo.tmp_15x11_TotalesFilas as a where a.grupo=n.grupo and a.num_conc=3999)))) as centro,'
								+ 'null as ocupacion,'
								+ ''' '' as clase,'
								+ 'null as horario,'
								+ 'sum(n.dias) as dias ,'
								+ 'sum(n.faltas) as faltas ,'
								+ 'sum(n.inc) as inc ,'
								+ 'sum(n.DsPrimVac) as DsPrimVac ,'
								+ 'sum(n.LabDsDesc) as LabDsDesc ,'
								+ 'sum(n.TpoExtDob) as TpoExtDob ,'
								+ 'sum(n.TpoExtTri) as TpoExtTri,'
								+ 'null as supervisor, '
								+ 'null as mes,'
								+ 'null as periodo,'
								+ ' 4 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								--+ '	WHERE     n.tipo<>4 '
								+ ' GROUP BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ ' n.num_conc ' 
								+ ' order BY n.grupo ,'
								+ ' n.nombreGrupo ,'
								+ ' n.num_conc ' 
								
					
			INSERT INTO dbo.tmp_15x11_TotalesFilas 
			EXEC(@tableString)
			
			--PRINT(@tableString)
			
			PRINT 'Por Grupo'
			
		
		--Inserta total general
			
			SET @tableString = ' '
			--select count(DISTINCT(a.codigo)) from dbo.tmp_15x11_TotalesFilas as a where a.codigo<>999999999
			SET @tableString = 'SELECT   ''999999999999999'' ,'
								+ ' ''TOTAL GENERAL'' ,'
								+ ' 0,'
								+ '999999999,' 
								+ 'n.num_conc,'
								+ ' '' '' as concepto,'
								+ 'SUM(isnull(n.importe,0)) as importe,'
								+ + '''Emps. '' + rtrim(ltrim(str((select count(DISTINCT(a.codigo)) from dbo.tmp_15x11_TotalesFilas as a where a.codigo<>999999999)))) as centro,'
								+ 'null as ocupacion,'
								+ ''' '' as clase,'
								+ 'null as horario,'
								+ 'sum(n.dias) as dias ,'
								+ 'sum(n.faltas) as faltas ,'
								+ 'sum(n.inc) as inc ,'
								+ 'sum(n.DsPrimVac) as DsPrimVac ,'
								+ 'sum(n.LabDsDesc) as LabDsDesc ,'
								+ 'sum(n.TpoExtDob) as TpoExtDob ,'
								+ 'sum(n.TpoExtTri) as TpoExtTri,'
								+ 'null as supervisor, '
								+ 'null as mes,'
								+ 'null as periodo,'
								+ ' 5 '
								+ '	FROM      dbo.tmp_15x11_TotalesFilas as n '
								+ ' where n.tipo<>4'
								+ ' GROUP BY n.num_conc ' 
								+ ' order BY n.num_conc ' 
								
					
			INSERT INTO dbo.tmp_15x11_TotalesFilas 
			EXEC(@tableString)
			
			PRINT 'General'
			
			--SELECT * FROM      dbo.tmp_15x11_TotalesFilas
			
	--Tabla Cruzada(
    SET @sqlStirng = 'SELECT empresa as Empresa,registro_patronal as ''Registro Patronal'','
							+ 'codigo as ''Cdigo'',' 
							+ 'isnull(nombre,nombreGrupo) as ''Nombre del empleado'', '
							+ 'rfc as ''R.F.C.'', '
							+ 'curp as ''CURP'', '
							+ 'convert(varchar(15),afiliacion) as ''No. Afiliacin'', '
							+ 'sindicato as ''Sind.'', '
							+ 'clase as ''Clase'','
							+ 'horario as ''Horario.'','
							+ 'centro as ''Centro'','
							+ 'nomdepto as ''Nombre del C.C.'','
							+ 'ocupacion as ''Tabulador'','
							+ 'actividad as ''Ocupacin'','
							+ 'supervisor as ''Supervisor'','
							+ 'alta as ''Fecha de Alta'','
							+ 'sueldo as ''Ultimo Sueldo'','
							+ 'saldiaint as ''Ultimo Integrado'','
							+ 'convert(varchar(5),manoobra) as ''Mano Obra'','
							+ 'dias as ''Dias'','
							+ 'faltas as ''Faltas'','
							+ 'inc as ''Inc'','
							+ 'DsPrimVac as ''Ds. Prima Vac'','
							+ 'LabDsDesc as ''Labs. da desc.'','
							+ 'TpoExtDob as ''Tpo Ext Doble'','
							+ 'TpoExtTri as ''Tpo Ext Triple'','
							+ @headerPivotStrind + ','
							+ 'cta_bco_no as ''Cta. Bancaria'','
							+ 'Banco,'
							+ 'cuenta as ''Cta. Contable'',convert(varchar,fch_baja,103) as ''Fecha Baja'',TipoContrato as ''TC'',convert(varchar(5),Sexo) Sexo,ClaveSat as ''Clave SAT'','
							+ 'iif(PorcientoSAT<=0,'''',convert(varchar,PorcientoSAT)) as ''%'',convert(varchar,fchnac,103) as ''Fecha Nac.'','
							+ 'periodo as ''Periodo'','
							+ 'mes as ''Mes'' '
        SET @sqlStirng2 = ' FROM    ( SELECT    k.grupo,k.nombreGrupo,k.empresa,em.registro_patronal,k.codigo,k.num_conc, ' 
							+ ' sum(k.importe) as importe,'
							+ ' cast(RTRIM(LTRIM(e.ap_paterno)) + '' '' + RTRIM(LTRIM(e.ap_materno)) + '' '' + RTRIM(LTRIM(e.nombre)) as varchar(50) )as nombre,'
							+ ' RTRIM(LTRIM(e.rfcalfa)) + ''-'' + RTRIM(LTRIM(e.rfcnum)) + ''-'' + RTRIM(LTRIM(e.rfchomo)) as rfc,'
							+ ' RTRIM(LTRIM(e.afiliacion)) + ''-'' + RTRIM(LTRIM(str(e.digvera))) as afiliacion,'
							+ ' cast(e.sindicato as varchar(5)) as sindicato,'
							+ ' cast(k.clase as varchar(5)) as clase,'
							+ ' k.horario,'
							+ ' cast(k.centro as varchar(20)) as centro,'
							+ ' (select MAX(c.nomdepto) from dbo.centros as c where c.centro=k.centro and c.centro<>'''') as nomdepto,'
							+ ' k.ocupacion,'
							+ ' (select MAX(t.actividad) from dbo.tabulador as t where t.ocupacion=k.ocupacion and t.empresa=k.empresa) as actividad,'
							+ ' k.supervisor,'
							+ ' CONVERT(NVARCHAR(30),e.fchalta,103) as alta,'
							+ ' e.sueldo,'
							+ ' e.saldiaint,'
							+ ' e.manoobra,'
							+ ' (SELECT a.dias FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS dias, '
							+ ' (SELECT a.faltas FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS faltas, '
							+ ' (SELECT a.inc FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS inc, '
							+ ' (SELECT a.DsPrimVac FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS DsPrimVac, '
							+ ' (SELECT a.LabDsDesc FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS LabDsDesc, '
							+ ' (SELECT a.TpoExtDob FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS TpoExtDob, '
							+ ' (SELECT a.TpoExtTri FROM  dbo.tmp_15x11_TotalesDiasHoras AS a WHERE a.nombreGrupo=k.nombreGrupo AND a.empresa=k.empresa AND a.codigo = k.codigo AND a.centro=k.centro AND a.ocupacion=k.ocupacion AND a.clase = k.clase AND a.horario=k.horario AND a.supervisor = k.supervisor AND a.mes=k.mes AND a.periodo=k.periodo) AS TpoExtTri, '
							+ ' e.cta_bco_no, '
							+ ' bn.nombre as Banco, '
							+ ' k.mes,'
							+ ' e.curp,e.cuenta,e.fch_baja,ea.TipoContrato,e.Sexo,ea.ClaveSat,ea.PorcientoSAT,e.fchnac,'
							+ ' k.periodo '
					+ ' FROM       dbo.tmp_15x11_TotalesFilas AS k ' 
					+ ' LEFT JOIN dbo.empleados as e on k.codigo=e.codigo and k.empresa=e.empresa'
					+ ' LEFT JOIN dbo.empresas as em on em.empresa=e.empresa'
					+ ' LEFT JOIN dbo.Llaves as l on l.empresa=e.empresa and l.codigo=e.codigo '
					+ ' LEFT JOIN dbo.bancos as bn on bn.banco=l.banco '
					+ ' LEFT JOIN dbo.EmpleadoAdicional as ea on ea.empresa=k.empresa and ea.codigo=k.codigo '
					--+ ' where k.tipo<>4'
					+ ' group by k.empresa,em.registro_patronal,k.grupo,k.nombreGrupo,k.codigo,k.num_conc, ' 
							+ ' e.curp,e.cuenta,e.fch_baja,ea.TipoContrato,e.Sexo,ea.ClaveSat,ea.PorcientoSAT,e.fchnac,'
							+ ' k.importe,'
							+ ' cast(RTRIM(LTRIM(e.ap_paterno)) + '' '' + RTRIM(LTRIM(e.ap_materno)) + '' '' + RTRIM(LTRIM(e.nombre)) as varchar(50) ),'
							+ ' RTRIM(LTRIM(e.rfcalfa)) + ''-'' + RTRIM(LTRIM(e.rfcnum)) + ''-'' + RTRIM(LTRIM(e.rfchomo)) ,'
							+ ' RTRIM(LTRIM(e.afiliacion)) + ''-'' + RTRIM(LTRIM(str(e.digvera))) ,'
							+ ' cast(e.sindicato as varchar(5)) ,'
							+ ' cast(k.clase as varchar(5)) ,'
							+ ' k.horario,'
							+ ' k.centro,'
							+ ' cast(k.centro as varchar(20)) ,'
							+ ' k.ocupacion,'
							+ ' k.supervisor,'
							+ ' k.clase,'
							+ ' CONVERT(NVARCHAR(30),e.fchalta,103),'
							+ ' e.sueldo,'
							+ ' e.saldiaint,'
							+ ' e.manoobra,'
							+ ' e.cta_bco_no, '
							+ ' k.mes,'
							+ ' bn.nombre,'
							+ ' k.periodo '
							
        + ') AS detail '
        + 'PIVOT ' + '( Sum( importe ) FOR num_conc IN ( '
        + @headerTypesStrind + ' ) ) AS PivotTable ' + ' ORDER BY grupo,codigo,periodo '
    
    
    EXECUTE( @sqlStirng + @sqlStirng2)
    
     
    IF OBJECT_ID('dbo.tmp_15x11_TotalesFilas') IS NOT NULL 
                BEGIN
                    DROP TABLE dbo.tmp_15x11_TotalesFilas
                END
                
	IF OBJECT_ID('dbo.tmp_15x11_Conceptos') IS NOT NULL 
                BEGIN
                    DROP TABLE dbo.tmp_15x11_Conceptos
                END
	IF OBJECT_ID('dbo.tmp_15x11_Empresas') IS NOT NULL 
                BEGIN
                    DROP TABLE dbo.tmp_15x11_Empresas
                END

GO



/**************************************************************************************************
 * Name          : PortalPatronObtenRFC
 * Project       : APSISISTEMAS
 * Description   : PortalPatronObtenRFC
 * Table name    : 
 * Copyright     : APSI SA, de CV 2010 - 2015. All rights reserved
 * Company       : APSI SA, de CV
 * Author        : adan.sanchez@apsi.com.mx
 * Creation date : viernes, 30 de enero de 2013
 **************************************************************************************************/
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.PortalPatronObtenRFC')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.PortalPatronObtenRFC
GO


CREATE PROCEDURE dbo.PortalPatronObtenRFC ( @keyId udtLong )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
   
    SELECT DISTINCT
            ( a.rfc_empresa ) AS RFC
    FROM    dbo.empresas AS a
            INNER JOIN dbo.tmpAccesoPortalPatron AS b ON a.empresa = b.empresa
    WHERE   b.llave = @keyId
   
   
GO


/**************************************************************************************************
 * Name          : PortalPatronObtenListadoSAT
 * Project       : APSISISTEMAS
 * Description   : PortalPatronObtenListadoSAT
 * Table name    : 
 * Copyright     : APSI SA, de CV 2010 - 2015. All rights reserved
 * Company       : APSI SA, de CV
 * Author        : adan.sanchez@apsi.com.mx
 * Creation date : viernes, 31 de enero de 2013
 **************************************************************************************************/
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.PortalPatronObtenListadoSAT')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.PortalPatronObtenListadoSAT
GO


CREATE PROCEDURE dbo.PortalPatronObtenListadoSAT
    (
      @nTypeReport udtInteger ,
      @rfcKey udtName ,
      @keyId udtLong 
    )
    --WITH ENCRYPTION
AS 
    IF @nTypeReport = 2 
        BEGIN
            SELECT  a.empresa ,
                    a.codigo ,
                    LTRIM(RTRIM(a.ap_paterno)) + ' '
                    + RTRIM(LTRIM(a.ap_materno)) + ' ' + LTRIM(RTRIM(a.nombre)) AS nombreCompleto,
                    a.curp ,
                    CONVERT(NVARCHAR(30), a.fchalta, 103) AS fchalta ,
                    a.saldiaint ,
                    e.rfc_empresa ,
                    LTRIM(RTRIM(a.ap_paterno)) AS paterno ,
                    RTRIM(LTRIM(a.ap_materno)) AS materno ,
                    LTRIM(RTRIM(a.nombre)) AS nombre,
                    CASE WHEN (a.saldiaint * 365)>= 400000.00 THEN 'SI' ELSE 'NO' END AS base,
                    '' AS sel,
                    'NO' AS sel2
            FROM    dbo.empleados AS a
                    INNER JOIN dbo.empresas AS e ON a.empresa = e.empresa
                                                    AND RTRIM(LTRIM(e.rfc_empresa)) = CASE WHEN LEN(@rfcKey)>0 THEN @rfcKey ELSE RTRIM(LTRIM(e.rfc_empresa)) END 
					INNER JOIN dbo.acum_emps AS b ON a.empresa = b.empresa
                                                         AND a.codigo = b.codigo
                                                         AND b.ejercicio = e.ayo_operacion
                    INNER JOIN dbo.tmpAccesoPortalPatron AS emp ON e.empresa = emp.empresa
                                                              AND emp.llave = @keyId
            WHERE   (YEAR(a.fch_baja) >= e.ayo_operacion OR a.fch_baja IS NULL)
            GROUP BY a.empresa ,
                    a.codigo ,
                    LTRIM(RTRIM(a.ap_paterno)) + ' '
                    + RTRIM(LTRIM(a.ap_materno)) + ' ' + LTRIM(RTRIM(a.nombre)) ,
                    a.curp ,
                    CONVERT(NVARCHAR(30), a.fchalta, 103) ,
                    a.saldiaint ,
                    e.rfc_empresa ,
                    LTRIM(RTRIM(a.ap_paterno)) ,
                    RTRIM(LTRIM(a.ap_materno)) ,
                    LTRIM(RTRIM(a.nombre))
            ORDER BY e.rfc_empresa ,a.codigo
        END
        IF @nTypeReport = 1
            BEGIN
                SELECT  a.empresa ,
                        a.codigo ,
                        LTRIM(RTRIM(a.ap_paterno)) + ' '
                        + RTRIM(LTRIM(a.ap_materno)) + ' '
                        + LTRIM(RTRIM(a.nombre)) AS nombreCompleto ,
                        a.curp ,
                        CONVERT(NVARCHAR(30), a.fchalta, 103) AS fchalta ,
                        a.saldiaint ,
                        e.rfc_empresa ,
                        LTRIM(RTRIM(a.ap_paterno)) AS paterno ,
                        RTRIM(LTRIM(a.ap_materno)) AS materno ,
                        LTRIM(RTRIM(a.nombre)) AS nombre,
                    CASE WHEN (a.saldiaint * 365)>= 400000.00 THEN 'SI' ELSE 'NO' END AS base,
                    '' AS sel,
                    'NO' AS sel2
                FROM    dbo.empleados AS a
                        INNER JOIN empresas AS e ON a.empresa = e.empresa
                                                    AND RTRIM(LTRIM(e.rfc_empresa)) = CASE WHEN LEN(@rfcKey)>0 THEN @rfcKey ELSE RTRIM(LTRIM(e.rfc_empresa)) END 
                        INNER JOIN dbo.avisos_imss AS b ON a.empresa = b.empresa
                                                         AND a.codigo = b.codigo
                                                         AND b.ayo_operacion = e.ayo_operacion
                                                         AND e.mes_operacion = b.mes_operacion
                                                         AND b.mov = 'A'
                        INNER JOIN dbo.tmpAccesoPortalPatron AS emp ON e.empresa = emp.empresa
                                                              AND emp.llave = @keyId
                --WHERE   a.activo = 'S'
                GROUP BY a.empresa ,
                        a.codigo ,
                        LTRIM(RTRIM(a.ap_paterno)) + ' '
                        + RTRIM(LTRIM(a.ap_materno)) + ' '
                        + LTRIM(RTRIM(a.nombre)) ,
                        a.curp ,
                        CONVERT(NVARCHAR(30), a.fchalta, 103) ,
                        a.saldiaint ,
                        e.rfc_empresa ,
                        LTRIM(RTRIM(a.ap_paterno)) ,
                        RTRIM(LTRIM(a.ap_materno)) ,
                        LTRIM(RTRIM(a.nombre))
                ORDER BY e.rfc_empresa ,a.codigo
            END

GO

/**************************************************************************************************
 * Project       : Portal del empleado
 * Description   : Crea la tabla de configuracin para el portal del empleado
 * Table name    : PortalEmpleadoBitacora
 * Copyright     : Apsi 2013- 2015. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Adn Snchez Mujica (adan.sanchez@apsi.com.mx)
 * Creation date : Jueves, 31/07/2013
 **************************************************************************************************/

IF NOT EXISTS ( SELECT  *
                FROM    dbo.sysobjects
                WHERE   id = OBJECT_ID(N'[dbo].[PortalEmpleadoConfig]')
                        AND OBJECTPROPERTY(id, N'IsUserTable') = 1 ) 
    BEGIN
        CREATE TABLE [dbo].[PortalEmpleadoConfig]
            (
              [llave] [int] NOT NULL
                            IDENTITY ,
              [emps_todas] VARCHAR(1)
                NULL
                CONSTRAINT [pk_PortalEmpleadoConfig]
                PRIMARY KEY CLUSTERED ( [llave] ASC )
            )
        ON  [PRIMARY]
        
        
        INSERT  INTO dbo.PortalEmpleadoConfig
                ( emps_todas )
        VALUES  ( 'N' )
    END

GO

IF NOT EXISTS ( SELECT  syscolumns.name
                FROM    syscolumns
                        LEFT JOIN sysobjects ON syscolumns.id = sysobjects.id
                WHERE   syscolumns.name = 'Autoriza'
                        AND sysobjects.name = 'PortalEmpleadoConfig' ) 
    ALTER TABLE PortalEmpleadoConfig ADD Autoriza VARCHAR(3) NULL 
GO



IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'ObtenRelojValidaPassword'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.ObtenRelojValidaPassword
GO

CREATE PROCEDURE dbo.ObtenRelojValidaPassword
    (
      @username AS udtName , --sin guiones ni espacios
      @password AS udtName
    )
	----WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    DECLARE @recordId AS udtId
    SET XACT_ABORT ON
    DECLARE @passwordDecrypt AS udtName
    DECLARE @passwordUser AS udtName
    DECLARE @userValid AS udtName
	
	
    SET @userValid = ISNULL(( SELECT    'Found'
                              FROM      dbo.usuarios
                              WHERE     usuario = @username
                            ), 'Not')
    IF @userValid = 'Not' 
        BEGIN
            SELECT  'UserNotFound' AS cLogin
		
        END
    ELSE 
        BEGIN
	
		
		
            SET @passwordUser = ( SELECT    password
                                  FROM      dbo.usuarios
                                  WHERE     usuario = @username
                                )
		
            SELECT  CASE WHEN BINARY_CHECKSUM(@passwordUser) = BINARY_CHECKSUM(@password)
                         THEN 'LoginSuccessfully'
                         WHEN BINARY_CHECKSUM(@passwordUser) <> BINARY_CHECKSUM(@password)
                         THEN 'IncorrectPassarod'
                    END AS cLogin
		
        END 
	
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenAdminPEEmpleadosActivos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenAdminPEEmpleadosActivos

GO

CREATE PROCEDURE dbo.ObtenAdminPEEmpleadosActivos ( @nFiltro udtInteger, @llave udtLong )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''


    SET @selectClause = 'SELECT  empresa ,codigo ,RTRIM(LTRIM(ap_paterno)) + '' '' + RTRIM(LTRIM(ap_materno)) + '' ''+ RTRIM(LTRIM(nombre)) AS nombre ,'''' AS sel ,''N'' AS sel2 '
					    
    SET @fromClause = ' FROM    dbo.empleados '
											    
    SET @whereClause = ' WHERE '
        + CASE WHEN @nFiltro = 1
               THEN 'activo = ''S'' AND ultmov <> ''B'' and isnull(borrado,''N'')= ''N'' '
               WHEN @nFiltro = 2
               THEN ' ultmov = ''B'' and isnull(borrado,''N'')= ''N'' '
               WHEN @nFiltro = 3 THEN ' isnull(borrado,''N'')= ''N'' '
          END +
          ' AND empresa in(select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
										
	
    SET @groupByClause = '  '
    
    SET @orderByClause = ' ORDER BY empresa,codigo '
    
             
    IF @debug = 0 
        BEGIN 
            EXEC(
            @selectClause + @fromClause + @whereClause + @groupByClause + @orderByClause
            )
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @fromClause + @whereClause
                    + @groupByClause + @orderByClause )
        END
        
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaAdminPEPassword')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaAdminPEPassword

GO

CREATE PROCEDURE dbo.ModificaAdminPEPassword
    (
      @codigos udtStringSize4096 ,
      @newPwd udtName,
      @llave udtLong
    )
    WITH ENCRYPTION
AS 
    DECLARE @selectClause udtStringSize255
    DECLARE @whereClause udtStringSize255
    DECLARE @whereClauseEnd udtStringSize255
    DECLARE @debug udtInteger
	
    SET @debug = 0
	
    SET @selectClause = CASE WHEN @newPwd IS NULL
                                  OR @newPwd = 'NULL'
                             THEN 'UPDATE dbo.empleados set password_empleado=null '
                             ELSE 'UPDATE dbo.empleados set password_empleado= '''
                                  + @newPwd + ''' '
                        END 
    SET @whereClause = ' WHERE codigo in(' 
    SET @whereClauseEnd = ')' + ' AND empresa in(select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
	
    IF @debug = 0 
        BEGIN
            EXEC(@selectClause + @whereClause + @codigos + @whereClauseEnd)
        END
    ELSE 
        BEGIN
            PRINT ( @selectClause + @whereClause + @codigos + @whereClauseEnd )
        END
	
	

GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenAdminPEEmpleadosAccesos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenAdminPEEmpleadosAccesos

GO

CREATE PROCEDURE dbo.ObtenAdminPEEmpleadosAccesos
    (
      @inicio udtDateTime ,
      @termino udtDateTime
    )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    SELECT  a.codigo ,
            RTRIM(LTRIM(a.ap_paterno)) + ' ' + RTRIM(LTRIM(a.ap_materno))
            + ' ' + RTRIM(LTRIM(a.nombre)) AS nombreEmpleado ,
            b.fecha ,
            b.hora
    FROM    dbo.empleados AS a
            INNER JOIN dbo.PortalEmpleadoWebBitacora AS b ON a.empresa = b.empresa
                                                             AND a.codigo = b.codigo
    WHERE   b.fecha BETWEEN @inicio AND @termino
    ORDER BY a.codigo ASC ,
            b.fecha DESC ,
            b.hora DESC
        
        
GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtenAdminPEOtrasOpciones')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtenAdminPEOtrasOpciones

GO

CREATE PROCEDURE dbo.ObtenAdminPEOtrasOpciones
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    SELECT  emps_todas,
			ISNULL(Autoriza,'A')
    FROM    dbo.PortalEmpleadoConfig
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ModificaAdminPEOtrasOpciones')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ModificaAdminPEOtrasOpciones

GO

CREATE PROCEDURE dbo.ModificaAdminPEOtrasOpciones ( @todas_emps udtName,@autoriza udtName )
    WITH ENCRYPTION
AS 
    SET NOCOUNT ON

    UPDATE  dbo.PortalEmpleadoConfig
    SET     emps_todas = @todas_emps,
		    autoriza=@autoriza
        
        
GO

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtienePortalRecibosImpresosTiposNom')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtienePortalRecibosImpresosTiposNom
GO

CREATE PROCEDURE dbo.ObtienePortalRecibosImpresosTiposNom
    (
      @llave udtLong 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    
    SET @dataBaseName = ( SELECT    DB_NAME() AS [Current Database]
                        ) + '_CFDI'
    
    SET @sqlString = 'SELECT  DISTINCT(tiponom) '
        + 'FROM    ' + @dataBaseName + '.dbo.CFDI ' + 'WHERE   empresa in (select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
	
            EXECUTE ( @sqlString
                   )

GO 
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtienePortalRecibosImpresosEjercicios')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtienePortalRecibosImpresosEjercicios
GO

CREATE PROCEDURE dbo.ObtienePortalRecibosImpresosEjercicios
    (
      @tiponom udtInteger,
      @llave udtLong
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    
    SET @dataBaseName = ( SELECT    DB_NAME() AS [Current Database]
                        ) + '_CFDI'
    
    SET @sqlString = 'SELECT  DISTINCT(ayo_operacion) '
        + 'FROM    ' + @dataBaseName + '.dbo.CFDI ' 
        + 'WHERE   tiponom=' +RTRIM(LTRIM(STR(@tiponom)))
        + ' AND empresa in (select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
	
            EXECUTE ( @sqlString
                   )

GO 
IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtienePortalRecibosImpresosPeriodos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtienePortalRecibosImpresosPeriodos
GO

CREATE PROCEDURE dbo.ObtienePortalRecibosImpresosPeriodos
    (
      @tiponom udtInteger,
      @ayo_operacion udtInteger,
      @llave udtLong
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    
    SET @dataBaseName = ( SELECT    DB_NAME() AS [Current Database]
                        ) + '_CFDI'
    
    SET @sqlString = 'SELECT  DISTINCT(periodo) '
        + 'FROM    ' + @dataBaseName + '.dbo.CFDI ' 
        + 'WHERE   tiponom=' +RTRIM(LTRIM(STR(@tiponom)))
        + ' AND ayo_operacion = ' +RTRIM(LTRIM(STR(@ayo_operacion)))
        + ' AND empresa in (select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
        + ' ORDER BY periodo DESC'
	
            EXECUTE ( @sqlString
                   )

GO 

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtienePortalRecibosImpresosNominas')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtienePortalRecibosImpresosNominas
GO

CREATE PROCEDURE dbo.ObtienePortalRecibosImpresosNominas
    (
      @tiponom udtInteger,
      @ayo_operacion udtInteger,
      @periodo udtInteger,
      @llave udtLong
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    
    SET @dataBaseName = ( SELECT    DB_NAME() AS [Current Database]
                        ) + '_CFDI'
    
    SET @sqlString = 'SELECT  DISTINCT(nomina) '
        + 'FROM    ' + @dataBaseName + '.dbo.CFDI ' 
        + 'WHERE   tiponom=' +RTRIM(LTRIM(STR(@tiponom)))
        + ' AND ayo_operacion = ' +RTRIM(LTRIM(STR(@ayo_operacion)))
        + ' AND periodo = ' +RTRIM(LTRIM(STR(@periodo)))
        + ' AND empresa in (select empresa from dbo.tmpAccesoPortalPatron where llave='+ RTRIM(LTRIM(STR(@llave))) + ' )'
	
            EXECUTE ( @sqlString
                   )

GO 


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.ObtienePortalRecibosImpresos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.ObtienePortalRecibosImpresos
GO

CREATE PROCEDURE dbo.ObtienePortalRecibosImpresos
    (
      @tiponom udtInteger,
      @nomina udtName ,
      @ayo_operacion udtInteger ,
      @periodo udtInteger ,
      @Orden udtInteger,
      @Reporte udtInteger,
      @Todos udtName,
      @llave udtLong 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    DECLARE @empresas AS TABLE ( empresa udtInteger )
    DECLARE @recibos AS TABLE
        (
          empresa udtInteger ,
          codigo udtInteger ,
          impreso udtLong ,
          descargado udtLong ,
          enviado udtLong ,
          xmlDescargado udtLong
        )
    
    INSERT  @empresas
            ( empresa 
            )
            SELECT  empresa
            FROM    dbo.tmpAccesoPortalPatron
            WHERE   llave = @llave
    
    SET @dataBaseName = ( SELECT    DB_NAME() AS [Current Database]
                        ) + '_CFDI'
    
    SET @sqlString = 'SELECT  empresa , ' + 'codigo , ' + 'impreso , '
        + 'descargado , ' + 'enviado, ' + 'xmlDescargado '
        + 'FROM    ' + @dataBaseName + '.dbo.CFDI ' + 'WHERE   ayo_operacion = ' + RTRIM(LTRIM(STR(@ayo_operacion))) 
        + ' AND periodo = ' + RTRIM(LTRIM(STR(@periodo))) 
        + ' AND tiponom = ' + RTRIM(LTRIM(STR(@tiponom))) 
        + ' AND nomina = ''' + @nomina + ''''
	
    INSERT  INTO @recibos
            ( empresa ,
              codigo ,
              impreso ,
              descargado ,
              enviado ,
              xmlDescargado
	        
            )
            EXECUTE ( @sqlString
                   )
	SELECT empresa,codigo,nombreEmpleado,grupo,nombreGrupo, impreso ,vecesImpreso,PDFdescargado ,vecesPDFDescargado,xmlDescargado ,vecesxmlDescargado,enviado ,vecesEnviado
	FROM (
    SELECT  a.empresa ,
            a.codigo ,
            RTRIM(LTRIM(b.ap_paterno)) + ' ' + RTRIM(LTRIM(b.ap_materno)) + ' ' + RTRIM(LTRIM(b.nombre)) AS nombreEmpleado,
            CASE	WHEN @Orden = 1 THEN REPLICATE('0',15 - LEN(RTRIM(LTRIM(d.centro)))) + RTRIM(LTRIM(d.centro))
					WHEN @Orden = 2 THEN REPLICATE('0',15 - LEN(RTRIM(LTRIM(STR(d.ocupacion))))) + RTRIM(LTRIM(STR(d.ocupacion)))
					WHEN @Orden = 3 THEN REPLICATE('0',15 - LEN(RTRIM(LTRIM(STR(d.supervisor))))) + RTRIM(LTRIM(STR(d.supervisor)))
            END AS grupo,
            CASE	WHEN @Orden = 1 THEN RTRIM(LTRIM(d.centro)) + ' ' + e.nomdepto
					WHEN @Orden = 2 THEN RTRIM(LTRIM(STR(d.ocupacion))) + ' ' + f.actividad
					WHEN @Orden = 3 THEN RTRIM(LTRIM(STR(d.supervisor))) + ' ' + g.nombre
            END AS nombreGrupo,
            CASE WHEN ISNULL(a.impreso, 0) <= 0 THEN 'NO'
                 ELSE 'SI'
            END AS impreso ,
            ISNULL(a.impreso, 0) AS vecesImpreso,
            CASE WHEN ISNULL(a.descargado, 0) <= 0 THEN 'NO'
                 ELSE 'SI'
            END AS PDFdescargado ,
            ISNULL(a.descargado, 0) AS vecesPDFDescargado,
            CASE WHEN ISNULL(a.descargado, 0) <= 0 THEN 'NO'
                 ELSE 'SI'
            END AS xmlDescargado ,
            ISNULL(a.xmlDescargado, 0) AS vecesxmlDescargado,
            CASE WHEN ISNULL(a.enviado, 0) <= 0 THEN 'NO'
                 ELSE 'SI'
            END AS enviado ,
            ISNULL(a.enviado, 0) AS vecesEnviado
    FROM    @recibos AS a
            INNER JOIN dbo.empleados AS b ON a.codigo = b.codigo
                                             AND a.empresa = b.empresa
            INNER JOIN dbo.Llaves AS d ON b.empresa = d.empresa
                                          AND b.codigo = d.codigo
            INNER JOIN dbo.supervisores AS g ON d.empresa = g.empresa
                                                AND d.supervisor = g.supervisor
            INNER JOIN dbo.tabulador AS f ON d.empresa = f.empresa
                                             AND d.ocupacion = f.ocupacion
            INNER JOIN dbo.centros AS e ON d.centro = e.centro
                                           AND d.empresa = e.empresa
            INNER JOIN @empresas AS c ON b.empresa = c.empresa) AS tblRows
            WHERE CASE	WHEN @Reporte = 1 THEN 0 
						WHEN @Reporte = 3 THEN ISNULL(tblRows.vecesImpreso,0)
						WHEN @Reporte = 5 THEN (ISNULL(tblRows.vecesPDFDescargado,0) + ISNULL(tblRows.vecesxmlDescargado,0))
						WHEN @Reporte = 7 THEN ISNULL(tblRows.vecesEnviado,0)
						ELSE 0
				  END <= 0
            
            ORDER BY tblRows.grupo,tblRows.empresa,tblRows.codigo

GO 

IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.portalDetalladoConceptos')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.portalDetalladoConceptos
GO

CREATE PROCEDURE dbo.portalDetalladoConceptos
    (
      @tiponom udtInteger,
      @nominas udtName ,
      @ayo_operacion udtInteger ,
      @periodo udtInteger ,
      @cMes varchar(1028),
	  @TipoReporte int,
	  @NombreEmpresa varchar(200),
      @llave udtLong 
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON
    
    DECLARE @dataBaseName AS udtName
    DECLARE @sqlString AS udtStringSize4096
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger
	--select * from dbo.tmpAccesoPortalPatron --AS b ON a.empresa = b.empresa
                                                         --AND b.llave = @keyId
	Set @selectClause = 'Select '
						+case when @TipoReporte = 1 then 'convert(varchar,a.Codigo) AS Codigo,rtrim(ltrim(emp.ap_paterno)) + '' '' + rtrim(ltrim(emp.ap_materno)) + '' '' + rtrim(ltrim(emp.nombre)) as Nombre,'
						else 'rtrim(isnull(c.centro,l.centro)) as Codigo,rtrim(cn.nomdepto) as Nombre,' end
						+'a.num_conc,max(a.concepto),sum(case when a.num_conc in(1,2,3,4,5,6,7,30, 108,109,110,111) then a.dias when a.num_conc in(10,11,12,13,120) then a.horas else 0 end) DiasHoras,Sum(a.importe) as Total,sum(a.igravable) as Gravable,sum(a.iexento) as Exento,sum(a.variaimss) as Integrable,sum(a.varia1) as I,sum(a.varia2) as J,Sum(a.varia3) as K,sum(a.varia4) as L,'
						+'case when a.tpago_desc=''P'' then 1 when a.tpago_desc=''D'' then 2 else 3 end as TipoConc,'
						+'rtrim(isnull(c.centro,l.centro)) as Centro,rtrim(cn.nomdepto) as NombreCentro '
	set @fromClause =	' From dbo.kardex_anual as a '
						+' inner join dbo.empleados as emp on emp.empresa=a.empresa and emp.codigo=a.codigo '
						+' inner join dbo.llaves as l on l.empresa=emp.empresa and l.codigo=emp.codigo '
						+' inner join dbo.tmpAccesoPortalPatron as b on b.empresa=a.empresa '
						+ ' outer apply (select top 1 centro from dbo.nomina1_anual '
						+ '	where empresa=a.empresa and codigo=a.codigo and periodo=a.periodo and ayo_operacion=a.ayo_operacion and nomina=''ORD'') as c '
						--+' left join dbo.nomina1_anual as c on c.empresa=a.empresa and c.codigo=a.codigo and c.periodo=a.periodo and c.ayo_operacion=a.ayo_operacion and c.nomina=''ORD'' '
						+' inner join dbo.centros as cn on cn.empresa=a.empresa and cn.centro=isnull(c.centro,l.centro) '
	set @whereClause =	' Where b.llave = ' + RTRIM(ltrim(str(@llave)))
						+ case when @tiponom>0 then ' and a.tiponom='+RTRIM(ltrim(str(@tiponom)))+' ' else '' end
						+ case when @ayo_operacion>0 then ' and a.ayo_operacion='+RTRIM(ltrim(str(@ayo_operacion)))+' ' else '' end
						+ case when @periodo>0 then ' and a.periodo='+RTRIM(ltrim(str(@periodo)))+' 'else '' end
						+ case when len(@nominas)>0 then ' and a.nomina in('+@nominas+') ' else ' ' end
						+ case when len(@cMes)>0 then ' and a.mes='''+@cMes+''' ' else ' ' end
	set @groupByClause = ' Group by '
						 + case when @TipoReporte=1 then 'convert(varchar,a.Codigo),rtrim(ltrim(emp.ap_paterno)) + '' '' + rtrim(ltrim(emp.ap_materno)) + '' ''+ rtrim(ltrim(emp.nombre))'
						 else 'isnull(c.centro,l.centro),cn.nomdepto'
						 end
						 + ',tpago_desc,num_conc,isnull(c.centro,l.centro),cn.nomdepto'
	set @orderByClause = ' Order by '
						 + case when @TipoReporte=1 then 'convert(varchar,a.Codigo) '
						 else 'isnull(c.centro,l.centro) '
						 end
						 +',case when a.tpago_desc=''P'' then 1 when a.tpago_desc=''D'' then 2 else 3 end,a.num_conc '

	
	Declare @Detalle as table(Codigo varchar(250),Nombre varchar(250),num_conc int,concepto varchar(150),DiasHoras numeric(10,2),Total Decimal(14,2),Gravable Decimal(14,2),Exento Decimal(14,2),Integrable Decimal(14,2),I Decimal(14,2),J Decimal(14,2),K Decimal(14,2),L Decimal(14,2),TipoConc int, Centro varchar(50),NombreCentro varchar(150))
	
	--Print(@selectClause+@fromClause+@whereClause+@groupByClause+@orderByClause)
	insert into @Detalle
	exec(@selectClause+@fromClause+@whereClause+@groupByClause+@orderByClause)

	insert into @Detalle
	select	'99999999',@NombreEmpresa,num_conc,max(concepto),
			SUM(DiasHoras),sum(Total),sum(Gravable),
			sum(Exento),sum(Integrable),
			Sum(i),sum(J),Sum(K),Sum(L),
			TipoConc,
			case when @TipoReporte=2 then 99999999 else null end centro,
			case when @TipoReporte=2 then @NombreEmpresa else null end nombrecentro
	from @Detalle
	Group by num_conc,TipoConc

	if @TipoReporte=1
	begin
		delete @Detalle where codigo<>'99999999'
	end

	select *
	from @Detalle
	order by codigo
	


GO


IF EXISTS ( SELECT  *
            FROM    dbo.sysobjects
            WHERE   id = OBJECT_ID(N'dbo.Obten_PortalPatronReporteEmpleados')
                    AND OBJECTPROPERTY(id, N'IsProcedure') = 1 ) 
    DROP PROCEDURE dbo.Obten_PortalPatronReporteEmpleados
GO


CREATE PROCEDURE dbo.Obten_PortalPatronReporteEmpleados
    (
      @fechaInicio udtName,
      @fechaTermino udtName,
      @nOrden udtInteger,
      @llave udtInteger
    )
    --WITH ENCRYPTION
AS 
    SET NOCOUNT ON 
    SET DATEFORMAT DMY
    
    DECLARE @fromClause udtStringSize4096
    DECLARE @selectClause udtStringSize4096
    DECLARE @whereClause udtStringSize4096
    DECLARE @groupByClause udtStringSize4096
    DECLARE @orderByClause udtStringSize4096
    DECLARE @title udtStringSize4096
    DECLARE @whereClauseUsed AS udtBoolean
    DECLARE @debug udtInteger

    SET @debug = 0
    SET @whereClauseUsed = 0
    SET @whereClause = ''
    SET @orderByClause = ''

	select *
	from(
			SELECT	a.codigo AS Codigo,
					RTRIM(a.ap_paterno) + ' ' + RTRIM(a.ap_materno) + ' ' + RTRIM(a.nombre) AS 'NombredelEmpleado',
					RTRIM(a.afiliacion) + '-' + RTRIM(a.digvera) AS 'Afiliacion',
					RTRIM(a.rfcalfa) + '-' + LTRIM(a.rfcnum) + '-' + RTRIM(a.rfchomo) AS 'R.F.C.',
					convert(nvarchar(30),a.fchalta,103) AS 'FechaAlta',
					isnull(convert(nvarchar(30),bj.fch_mov,103),iif(a.fch_baja is null or a.fch_baja='19000101','',convert(nvarchar(30),a.fch_baja,103))) AS 'FechaBaja',
					isnull(sdo.sueldo,a.sueldo) AS Sueldo,
					isnull(sdo.saldiaint,a.saldiaint) AS 'S.D.I.',
					--a.sueldo AS SueldoE,
					--a.saldiaint AS 'S.D.I. E',
					l.clase AS Clase,
					RTRIM(c.centro) + ' ' + RTRIM(c.nomdepto) AS Centro,
					a.sindicato 'Sind/Conf',
					t.actividad AS 'Ocupacion',
					convert(nvarchar(30),a.fchantigua,103) AS 'FechaAntigedad',
					a.cuenta as 'CtaContable',
					a.pagar_nomina as nomina,
					a.empresa,
					bj.fch_mov as BajaAI
					--,iif(a.fchalta <=@fechaTermino and  case when isnull(a.fch_baja,'19000101') = '19000101' then @fechaTermino else a.fch_baja end >= @fechaInicio,'S','N') as Activo,					sdo.fch_mov
			FROM dbo.empleados AS a 
			--INNER JOIN dbo.reportePatronEmpleadosSueldos AS sdo ON a.empresa = sdo.empresa AND a.codigo = sdo.codigo 
			--INNER JOIN dbo.reportePatronEmpleados AS emps ON a.empresa = emps.empresa AND a.codigo = emps.codigo 
			INNER JOIN dbo.Llaves AS l ON a.empresa = l.empresa AND a.codigo = l.codigo 
			INNER JOIN dbo.centros AS c ON l.centro = c.centro AND l.empresa = c.empresa 
			INNER JOIN dbo.tabulador AS t ON l.empresa=t.empresa AND l.ocupacion=t.ocupacion 
			INNER JOIN dbo.tmpAccesoPortalPatron as b on  a.empresa=b.empresa and b.llave=       @llave 
			--left join dbo.EmpleadoAdicional as ea on ea.empresa=a.empresa and ea.codigo=a.codigo
			outer apply(	select top 1 a1.fch_mov,a1.sueldo,a1.saldiaint--a.empresa,a.codigo,a.mov,a.fch_mov,a.sueldo,a.saldiaint,dense_rank() OVER ( PARTITION  BY a.codigo ORDER BY a.fch_mov,a.serial ) 
							from dbo.avisos_imss as a1
							--inner join dbo.reportePatronEmpleados  as b on a.empresa=b.empresa and a.codigo = b.codigo
							--where case when @fechaInicio= @fechaTermino then a.fch_mov<=@fechaTermino  else a.fch_mov >= @fechaInicio AND a.fch_mov<=@fechaTermino end
							where	a1.empresa=a.empresa and a1.codigo=a.codigo
									and (	(@fechaInicio= @fechaTermino and a1.fch_mov<=@fechaTermino) or 
											(a1.fch_mov >= @fechaInicio AND a1.fch_mov<=@fechaTermino)
										)
									and a1.mov in('A','IM','RI','MS')
							order by a1.fch_mov desc
							) as sdo
			outer apply(	select top 1 iif(a1.mov<>'B',null,a1.fch_mov) fch_mov,a1.sueldo,a1.saldiaint--a.empresa,a.codigo,a.mov,a.fch_mov,a.sueldo,a.saldiaint,dense_rank() OVER ( PARTITION  BY a.codigo ORDER BY a.fch_mov,a.serial ) 
							from dbo.avisos_imss as a1
							--inner join dbo.reportePatronEmpleados  as b on a.empresa=b.empresa and a.codigo = b.codigo
							--where case when @fechaInicio= @fechaTermino then a.fch_mov<=@fechaTermino  else a.fch_mov >= @fechaInicio AND a.fch_mov<=@fechaTermino end
							where	a1.empresa=a.empresa and a1.codigo=a.codigo
									--and (	(@fechaInicio= @fechaTermino and a1.fch_mov<=@fechaTermino) or 
									--		(a1.fch_mov >= @fechaInicio AND a1.fch_mov<=@fechaTermino)
									--	)
									and a1.fch_mov <=@fechaTermino 
									--and a1.mov in('B')
							order by a1.fch_mov desc, a1.serial desc
							) as bj
			--where	(a.fchalta <=@fechaTermino and  case when isnull(a.fch_baja,'19000101') = '19000101' then @fechaTermino else isnull(bj.fch_mov,a.fch_baja) end >= @fechaInicio)
			where	(a.fchalta <=@fechaTermino and  case when isnull(bj.fch_mov,isnull(a.fch_baja,'19000101')) = '19000101' then @fechaTermino else isnull(bj.fch_mov,a.fch_baja) end >= @fechaInicio)		
					and isnull(a.borrado,'N')='N'
			--GROUP BY a.codigo,RTRIM(a.ap_paterno) + ' ' + RTRIM(a.ap_materno) + ' ' + RTRIM(a.nombre),RTRIM(a.afiliacion) + '-' + RTRIM(a.digvera),RTRIM(a.rfcalfa) + '-' + LTRIM(a.rfcnum) + '-' + RTRIM(a.rfchomo),sdo.sueldo,sdo.saldiaint,l.clase,RTRIM(c.centro) + ' ' + RTRIM(c.nomdepto),a.sindicato ,t.actividad  
	) as Tbl
	--where	AltaMayor<>'N'
	--		or BajaMayor<>'N'
	ORDER BY  codigo 
	    
		
GO

